// Types
interface CheckoutInfo {
  email: string;
  phone: string;
  firstName: string;
  lastName: string;
  address: string;
  address2?: string;
  city: string;
  province: string;
  postalCode: string;
  ageVerification: boolean;
  orderId?: string;
  orderDate?: string;
  orderStatus?: 'pending' | 'confirmed' | 'shipped' | 'delivered';
  paymentStatus?: 'pending' | 'completed';
  trackingNumber?: string;
  trackingUrl?: string;
  adminNotes?: string[];
  shippingDate?: string;
  deliveryDate?: string;
  id?: string; // Added to support older order formats
}

// Define CartItem for Order
interface CartItem {
  productId: number;
  quantity: number;
  name?: string;
  price?: number;
}

// Expose Order type for use by TypeScript
type Order = CheckoutInfo & {
  items: CartItem[];
  total: number;
  dateCreated: string;
  location?: string;
  id?: string; // Added to support older order formats
  orderId?: string; // Support both formats
};

// Define the product interface
interface Product {
  id: number;
  category: string;
  name: string;
  price: number;
  rating: number;
  image: string;
  soldOut?: boolean;
}

// Define support message interface
interface SupportMessage {
  id?: number;
  orderNumber: string;
  message: string;
  createdAt: string;
  isRead: boolean;
  reply?: string;
  replyDate?: string;
  customerEmail?: string;
  customerName?: string;
}

// Global state
let currentOrderId: string | null = null;
let currentMessageId: number | null = null;
let currentProductId: number | null = null;
let products: Product[] = [];
let orders: Order[] = [];
let supportMessages: SupportMessage[] = [];

// DOM Element cache
const DOMElements = {
  // Navigation and Pages
  navLinks: document.querySelectorAll('.admin-nav a'),
  adminPages: document.querySelectorAll('.admin-page'),
  pageTitle: document.getElementById('page-title') as HTMLElement,

  // Orders
  ordersTable: document.getElementById('orders-table') as HTMLTableElement,
  ordersList: document.getElementById('orders-list') as HTMLElement,
  orderSearch: document.getElementById('order-search') as HTMLInputElement,
  searchBtn: document.getElementById('search-btn') as HTMLButtonElement,

  // Support Messages
  messagesList: document.getElementById('messages-list') as HTMLElement,
  unreadCount: document.getElementById('unread-count') as HTMLElement,

  // Products
  productsList: document.getElementById('products-list') as HTMLElement,
  addProductBtn: document.getElementById('add-product-btn') as HTMLButtonElement,

  // Order Modal
  orderModal: document.getElementById('order-modal') as HTMLElement,
  modalOrderId: document.getElementById('modal-order-id') as HTMLElement,
  orderForm: document.getElementById('order-form') as HTMLFormElement,
  closeOrderModal: document.getElementById('close-order-modal') as HTMLElement,
  orderStatus: document.getElementById('order-status') as HTMLSelectElement,
  paymentStatus: document.getElementById('payment-status') as HTMLSelectElement,
  trackingNumber: document.getElementById('tracking-number') as HTMLInputElement,
  trackingUrl: document.getElementById('tracking-url') as HTMLInputElement,
  shippingDate: document.getElementById('shipping-date') as HTMLInputElement,
  deliveryDate: document.getElementById('delivery-date') as HTMLInputElement,
  adminNote: document.getElementById('admin-note') as HTMLTextAreaElement,
  adminNotesList: document.getElementById('admin-notes-list') as HTMLElement,
  customerName: document.getElementById('customer-name') as HTMLElement,
  customerEmail: document.getElementById('customer-email') as HTMLElement,
  customerPhone: document.getElementById('customer-phone') as HTMLElement,
  customerAddress: document.getElementById('customer-address') as HTMLElement,

  // Message Reply Modal
  replyModal: document.getElementById('reply-modal') as HTMLElement,
  closeReplyModal: document.getElementById('close-reply-modal') as HTMLElement,
  messageOrderId: document.getElementById('message-order-id') as HTMLElement,
  customerMessage: document.getElementById('customer-message') as HTMLElement,
  replyForm: document.getElementById('reply-form') as HTMLFormElement,
  replyMessage: document.getElementById('reply-message') as HTMLTextAreaElement,
  messageId: document.getElementById('message-id') as HTMLInputElement,
  markReadBtn: document.getElementById('mark-read-btn') as HTMLButtonElement,
  addToNotes: document.getElementById('add-to-notes') as HTMLInputElement,

  // Product Modal
  productModal: document.getElementById('product-modal') as HTMLElement,
  productModalTitle: document.getElementById('product-modal-title') as HTMLElement,
  productIdDisplay: document.getElementById('product-id-display') as HTMLElement,
  closeProductModal: document.getElementById('close-product-modal') as HTMLElement,
  productForm: document.getElementById('product-form') as HTMLFormElement,
  productName: document.getElementById('product-name') as HTMLInputElement,
  productCategory: document.getElementById('product-category') as HTMLInputElement,
  productPrice: document.getElementById('product-price') as HTMLInputElement,
  productRating: document.getElementById('product-rating') as HTMLInputElement,
  productImage: document.getElementById('product-image') as HTMLInputElement,
  productSoldOut: document.getElementById('product-sold-out') as HTMLInputElement,
  imagePreview: document.getElementById('image-preview') as HTMLElement,
  productId: document.getElementById('product-id') as HTMLInputElement,
  deleteProductBtn: document.getElementById('delete-product-btn') as HTMLButtonElement,

  modalOverlay: document.getElementById('modal-overlay') as HTMLElement,
  logoutLink: document.getElementById('logout-link') as HTMLElement
};

// Generate sample orders if none exist
function generateSampleOrders(): Order[] {
  // Define some sample orders
  const sampleOrders: Order[] = [
    {
      id: '1001',
      firstName: 'John',
      lastName: 'Doe',
      email: 'john.doe@example.com',
      phone: '(555) 123-4567',
      address: '123 Main St',
      city: 'Toronto',
      province: 'ON',
      postalCode: 'M5V 2K7',
      ageVerification: true,
      orderStatus: 'delivered',
      paymentStatus: 'completed',
      trackingNumber: 'TRK123456789',
      trackingUrl: 'https://example.com/track',
      dateCreated: '2023-12-01T10:30:00.000Z',
      shippingDate: '2023-12-02',
      deliveryDate: '2023-12-05',
      items: [
        { productId: 1, quantity: 2, name: 'Canada Tobacco Original', price: 50.00 },
        { productId: 3, quantity: 1, name: 'Canada Full Flavour', price: 50.00 }
      ],
      total: 150.00,
      adminNotes: ['Customer requested discreet packaging', 'Delivery confirmed via phone']
    },
    {
      id: '1002',
      firstName: 'Jane',
      lastName: 'Smith',
      email: 'jane.smith@example.com',
      phone: '(555) 987-6543',
      address: '456 Oak Ave',
      city: 'Vancouver',
      province: 'BC',
      postalCode: 'V6B 2E1',
      ageVerification: true,
      orderStatus: 'shipped',
      paymentStatus: 'completed',
      trackingNumber: 'TRK987654321',
      dateCreated: '2023-12-10T14:45:00.000Z',
      shippingDate: '2023-12-11',
      items: [
        { productId: 2, quantity: 1, name: 'Canada Tobacco Silver', price: 50.00 },
        { productId: 5, quantity: 2, name: 'Canada Menthol', price: 50.00 }
      ],
      total: 150.00
    },
    {
      id: '1003',
      firstName: 'Robert',
      lastName: 'Johnson',
      email: 'robert.j@example.com',
      phone: '(555) 555-1212',
      address: '789 Pine St',
      address2: 'Apt 3B',
      city: 'Montreal',
      province: 'QC',
      postalCode: 'H2Y 2W7',
      ageVerification: true,
      orderStatus: 'pending',
      paymentStatus: 'pending',
      dateCreated: new Date().toISOString(),
      items: [
        { productId: 4, quantity: 3, name: 'Canada Lights Cigarettes', price: 50.00 }
      ],
      total: 150.00
    }
  ];

  // Save to localStorage
  localStorage.setItem('orders', JSON.stringify(sampleOrders));
  return sampleOrders;
}

// Generate sample support messages if none exist
function generateSampleSupportMessages(): SupportMessage[] {
  // Define some sample messages
  const sampleMessages: SupportMessage[] = [
    {
      id: 1,
      orderNumber: '1001',
      message: 'I would like to check on the status of my order. It\'s been a week and I haven\'t received any updates.',
      createdAt: '2023-12-03T09:15:00.000Z',
      isRead: true,
      reply: 'Thank you for your message. Your order has been shipped and should arrive within 2-3 business days. The tracking number is TRK123456789.',
      replyDate: '2023-12-03T10:30:00.000Z',
      customerEmail: 'john.doe@example.com',
      customerName: 'John Doe'
    },
    {
      id: 2,
      orderNumber: '1002',
      message: 'Can I change my shipping address for order #1002? I would like it delivered to my work address instead.',
      createdAt: '2023-12-11T16:20:00.000Z',
      isRead: false,
      customerEmail: 'jane.smith@example.com',
      customerName: 'Jane Smith'
    },
    {
      id: 3,
      orderNumber: '1003',
      message: 'I just placed an order but I think I made a mistake with the quantity. Can you please update it?',
      createdAt: new Date().toISOString(),
      isRead: false,
      customerEmail: 'robert.j@example.com',
      customerName: 'Robert Johnson'
    }
  ];

  // Save to localStorage
  localStorage.setItem('supportMessages', JSON.stringify(sampleMessages));
  return sampleMessages;
}

// Load data from localStorage
function loadOrders(): void {
  const savedOrders = localStorage.getItem('orders');
  if (savedOrders) {
    try {
      orders = JSON.parse(savedOrders);
      renderOrders(orders);
    } catch (e) {
      console.error('Failed to parse saved orders:', e);
      orders = generateSampleOrders();
      renderOrders(orders);
    }
  } else {
    // Generate sample orders if none exist
    orders = generateSampleOrders();
    renderOrders(orders);
  }
}

// Load support messages
function loadSupportMessages(): void {
  const savedMessages = localStorage.getItem('supportMessages');
  if (savedMessages) {
    try {
      supportMessages = JSON.parse(savedMessages);
      renderSupportMessages(supportMessages);
      updateUnreadCount();
    } catch (e) {
      console.error('Failed to parse saved support messages:', e);
      supportMessages = generateSampleSupportMessages();
      renderSupportMessages(supportMessages);
      updateUnreadCount();
    }
  } else {
    // Generate sample messages if none exist
    supportMessages = generateSampleSupportMessages();
    renderSupportMessages(supportMessages);
    updateUnreadCount();
  }
}

// Load products
function loadProducts(): void {
  const savedProducts = localStorage.getItem('products');
  if (savedProducts) {
    try {
      products = JSON.parse(savedProducts);
      renderProducts();
    } catch (e) {
      console.error('Failed to parse saved products:', e);
      generateDefaultProducts();
      renderProducts();
    }
  } else {
    // Generate default products if none exist
    generateDefaultProducts();
    renderProducts();
  }
}

// Generate default products
function generateDefaultProducts(): void {
  products = [
    {
      id: 1,
      category: 'Canada Tobacco',
      name: 'Canada Tobacco Original',
      price: 50.00,
      rating: 5,
      image: 'https://ext.same-assets.com/698571986/674305779.jpeg',
      soldOut: false
    },
    {
      id: 2,
      category: 'Canada Tobacco',
      name: 'Canada Tobacco Silver',
      price: 50.00,
      rating: 5,
      image: 'https://ext.same-assets.com/698571986/3000929280.jpeg',
      soldOut: false
    },
    {
      id: 3,
      category: 'Canada Tobacco',
      name: 'Canada Full Flavour',
      price: 50.00,
      rating: 4,
      image: 'https://ext.same-assets.com/698571986/2061452602.jpeg',
      soldOut: false
    },
    {
      id: 4,
      category: 'Canada Tobacco',
      name: 'Canada Lights Cigarettes',
      price: 50.00,
      rating: 5,
      image: 'https://ext.same-assets.com/698571986/4081112461.jpeg',
      soldOut: false
    },
    {
      id: 5,
      category: 'Canada Tobacco',
      name: 'Canada Menthol',
      price: 50.00,
      rating: 5,
      image: 'https://ext.same-assets.com/698571986/1829912013.jpeg',
      soldOut: false
    },
    {
      id: 6,
      category: 'Canada Tobacco',
      name: 'Canada Premium Original Cigarettes',
      price: 50.00,
      rating: 5,
      image: 'https://ext.same-assets.com/698571986/174693145.jpeg',
      soldOut: false
    },
    {
      id: 7,
      category: 'Canada Tobacco',
      name: 'Canada Ultra Light Cigarettes',
      price: 50.00,
      rating: 5,
      image: 'https://ext.same-assets.com/698571986/2524349341.jpeg',
      soldOut: false
    }
  ];

  // Save to localStorage for admin and storefront use
  localStorage.setItem('products', JSON.stringify(products));
  localStorage.setItem('adminProducts', JSON.stringify(products));
}

// Render orders in the table
function renderOrders(ordersList: Order[]): void {
  // Sort orders by date (newest first)
  const sortedOrders = [...ordersList].sort((a, b) => {
    const dateA = new Date(a.dateCreated || '').getTime();
    const dateB = new Date(b.dateCreated || '').getTime();
    return dateB - dateA;
  });

  if (sortedOrders.length === 0) {
    DOMElements.ordersList.innerHTML = `
      <tr class="empty-state">
        <td colspan="7">No orders found</td>
      </tr>
    `;
    return;
  }

  DOMElements.ordersList.innerHTML = sortedOrders.map(order => {
    // Use order.orderId or order.id, whichever is available
    const orderId = order.orderId || order.id || '';
    const customerName = `${order.firstName} ${order.lastName}`;
    const orderDate = new Date(order.dateCreated).toLocaleDateString();
    const orderStatus = order.orderStatus || 'pending';
    const paymentStatus = order.paymentStatus || 'pending';

    return `
      <tr data-id="${orderId}">
        <td>#${orderId}</td>
        <td>${customerName}</td>
        <td>${orderDate}</td>
        <td>$${order.total.toFixed(2)}</td>
        <td><span class="status-badge ${paymentStatus}">${paymentStatus}</span></td>
        <td><span class="status-badge ${orderStatus}">${orderStatus}</span></td>
        <td>
          <button class="icon-button edit-order-btn" data-id="${orderId}">
            <span class="material-symbols-outlined">edit</span>
          </button>
        </td>
      </tr>
    `;
  }).join('');

  // Add event listeners to edit buttons
  document.querySelectorAll('.edit-order-btn').forEach(button => {
    button.addEventListener('click', (e) => {
      const target = e.currentTarget as HTMLElement;
      const orderId = target.getAttribute('data-id');
      if (orderId) {
        openOrderModal(orderId);
      }
    });
  });
}

// Render support messages
function renderSupportMessages(messagesList: SupportMessage[]): void {
  // Sort messages by date (newest first)
  const sortedMessages = [...messagesList].sort((a, b) => {
    const dateA = new Date(a.createdAt).getTime();
    const dateB = new Date(b.createdAt).getTime();
    return dateB - dateA;
  });

  if (sortedMessages.length === 0) {
    DOMElements.messagesList.innerHTML = `
      <tr class="empty-state">
        <td colspan="5">No support messages found</td>
      </tr>
    `;
    return;
  }

  DOMElements.messagesList.innerHTML = sortedMessages.map((message, index) => {
    const messageDate = new Date(message.createdAt).toLocaleDateString();
    const statusClass = message.isRead ? 'read' : 'unread';
    const statusText = message.isRead ? 'Read' : 'Unread';

    return `
      <tr data-id="${index}" class="${statusClass}">
        <td>#${message.orderNumber}</td>
        <td>${message.message.substring(0, 50)}${message.message.length > 50 ? '...' : ''}</td>
        <td>${messageDate}</td>
        <td><span class="status-badge ${statusClass}">${statusText}</span></td>
        <td>
          <button class="icon-button reply-btn" data-id="${index}">
            <span class="material-symbols-outlined">reply</span>
          </button>
        </td>
      </tr>
    `;
  }).join('');

  // Add event listeners to reply buttons
  document.querySelectorAll('.reply-btn').forEach(button => {
    button.addEventListener('click', (e) => {
      const target = e.currentTarget as HTMLElement;
      const messageId = parseInt(target.getAttribute('data-id') || '0', 10);
      openReplyModal(messageId);
    });
  });
}

// Update the unread count badge
function updateUnreadCount(): void {
  const unreadCount = supportMessages.filter(message => !message.isRead).length;
  if (unreadCount > 0) {
    DOMElements.unreadCount.textContent = unreadCount.toString();
    DOMElements.unreadCount.style.display = 'inline';
  } else {
    DOMElements.unreadCount.style.display = 'none';
  }
}

// Render products
function renderProducts(): void {
  if (products.length === 0) {
    DOMElements.productsList.innerHTML = `
      <tr class="empty-state">
        <td colspan="8">No products found</td>
      </tr>
    `;
    return;
  }

  DOMElements.productsList.innerHTML = products.map(product => {
    return `
      <tr data-id="${product.id}">
        <td>#${product.id}</td>
        <td><img src="${product.image}" alt="${product.name}" class="product-thumbnail"></td>
        <td>${product.name}</td>
        <td>${product.category}</td>
        <td>$${product.price.toFixed(2)}</td>
        <td>${'★'.repeat(product.rating)}${'☆'.repeat(5 - product.rating)}</td>
        <td><span class="status-badge ${product.soldOut ? 'sold-out' : 'in-stock'}">${product.soldOut ? 'Sold Out' : 'In Stock'}</span></td>
        <td>
          <button class="icon-button edit-product-btn" data-id="${product.id}">
            <span class="material-symbols-outlined">edit</span>
          </button>
        </td>
      </tr>
    `;
  }).join('');

  // Add event listeners to edit buttons
  document.querySelectorAll('.edit-product-btn').forEach(button => {
    button.addEventListener('click', (e) => {
      const target = e.currentTarget as HTMLElement;
      const productId = parseInt(target.getAttribute('data-id') || '0', 10);
      openProductModal(productId);
    });
  });
}

// Handle Modal Operations
function openOrderModal(orderId: string): void {
  currentOrderId = orderId;

  // Find the order
  const order = orders.find(o => (o.orderId || o.id) === orderId);
  if (!order) {
    console.error(`Order with ID ${orderId} not found`);
    return;
  }

  // Populate modal with order details
  DOMElements.modalOrderId.textContent = orderId;
  DOMElements.orderStatus.value = order.orderStatus || 'pending';
  DOMElements.paymentStatus.value = order.paymentStatus || 'pending';
  DOMElements.trackingNumber.value = order.trackingNumber || '';
  DOMElements.trackingUrl.value = order.trackingUrl || '';
  DOMElements.shippingDate.value = order.shippingDate || '';
  DOMElements.deliveryDate.value = order.deliveryDate || '';

  // Customer info
  DOMElements.customerName.textContent = `${order.firstName} ${order.lastName}`;
  DOMElements.customerEmail.textContent = order.email;
  DOMElements.customerPhone.textContent = order.phone;

  // Format address
  const address2 = order.address2 ? `${order.address2}, ` : '';
  DOMElements.customerAddress.textContent =
    `${order.address}, ${address2}${order.city}, ${order.province} ${order.postalCode}`;

  // Render admin notes if any
  renderAdminNotes(order.adminNotes || []);

  // Show modal
  DOMElements.orderModal.classList.add('active');
  DOMElements.modalOverlay.classList.add('active');
}

// Close order modal
function closeOrderModal(): void {
  DOMElements.orderModal.classList.remove('active');
  DOMElements.modalOverlay.classList.remove('active');
  currentOrderId = null;
  DOMElements.adminNote.value = '';
}

// Render admin notes
function renderAdminNotes(notes: string[]): void {
  if (notes.length === 0) {
    DOMElements.adminNotesList.innerHTML = '<p class="no-notes">No notes added yet</p>';
    return;
  }

  DOMElements.adminNotesList.innerHTML = notes.map((note) => {
    const date = new Date().toLocaleDateString();
    return `
      <div class="admin-note-item">
        <div class="note-content">${note}</div>
        <div class="note-date">Added on ${date}</div>
      </div>
    `;
  }).join('');
}

// Handle order form submission
function handleOrderFormSubmit(e: Event): void {
  e.preventDefault();

  if (!currentOrderId) return;

  // Find and update the order
  const orderIndex = orders.findIndex(o => (o.orderId || o.id) === currentOrderId);
  if (orderIndex === -1) return;

  const order = orders[orderIndex];

  // Update order details
  order.orderStatus = DOMElements.orderStatus.value as 'pending' | 'confirmed' | 'shipped' | 'delivered';
  order.paymentStatus = DOMElements.paymentStatus.value as 'pending' | 'completed';
  order.trackingNumber = DOMElements.trackingNumber.value;
  order.trackingUrl = DOMElements.trackingUrl.value;
  order.shippingDate = DOMElements.shippingDate.value;
  order.deliveryDate = DOMElements.deliveryDate.value;

  // Add note if provided
  const note = DOMElements.adminNote.value.trim();
  if (note) {
    if (!order.adminNotes) {
      order.adminNotes = [];
    }
    order.adminNotes.push(note);
    DOMElements.adminNote.value = '';
  }

  // Save updated orders to localStorage
  localStorage.setItem('orders', JSON.stringify(orders));

  // Re-render orders table and close modal
  renderOrders(orders);
  closeOrderModal();
}

// Support Message Modal Functionality
function openReplyModal(messageId: number): void {
  currentMessageId = messageId;

  // Find the message
  const message = supportMessages[messageId];
  if (!message) {
    console.error(`Message with ID ${messageId} not found`);
    return;
  }

  // Populate modal
  DOMElements.messageOrderId.textContent = message.orderNumber;
  DOMElements.customerMessage.textContent = message.message;
  DOMElements.messageId.value = messageId.toString();

  // Reset the form
  DOMElements.replyMessage.value = '';
  DOMElements.addToNotes.checked = false;

  // Show modal
  DOMElements.replyModal.classList.add('active');
  DOMElements.modalOverlay.classList.add('active');
}

// Close reply modal
function closeReplyModal(): void {
  DOMElements.replyModal.classList.remove('active');
  DOMElements.modalOverlay.classList.remove('active');
  currentMessageId = null;
}

// Mark message as read
function markMessageAsRead(): void {
  if (currentMessageId === null) return;

  const message = supportMessages[currentMessageId];
  if (!message) return;

  message.isRead = true;
  localStorage.setItem('supportMessages', JSON.stringify(supportMessages));

  renderSupportMessages(supportMessages);
  updateUnreadCount();

  // Close the modal
  closeReplyModal();
}

// Handle reply form submission
function handleReplyFormSubmit(e: Event): void {
  e.preventDefault();

  if (currentMessageId === null) return;

  const message = supportMessages[currentMessageId];
  if (!message) return;

  // Update message with reply
  const replyText = DOMElements.replyMessage.value.trim();
  if (replyText) {
    message.reply = replyText;
    message.replyDate = new Date().toISOString();
    message.isRead = true;

    // Add to order notes if checkbox is checked
    if (DOMElements.addToNotes.checked) {
      // Find the corresponding order
      const order = orders.find(o => (o.orderId || o.id) === message.orderNumber);
      if (order) {
        if (!order.adminNotes) {
          order.adminNotes = [];
        }
        order.adminNotes.push(`Reply to customer message: ${replyText}`);
        localStorage.setItem('orders', JSON.stringify(orders));
      }
    }

    // Save messages to localStorage
    localStorage.setItem('supportMessages', JSON.stringify(supportMessages));

    // Re-render support messages table and update unread count
    renderSupportMessages(supportMessages);
    updateUnreadCount();

    // Close the modal
    closeReplyModal();
  }
}

// Product Modal Functionality
function openProductModal(productId: number | null = null): void {
  currentProductId = productId;

  // Reset form
  DOMElements.productForm.reset();

  // Show image preview placeholder
  DOMElements.imagePreview.innerHTML = '<div class="empty-image">No Image Selected</div>';

  if (productId !== null) {
    // Edit existing product
    const product = products.find(p => p.id === productId);
    if (!product) {
      console.error(`Product with ID ${productId} not found`);
      return;
    }

    // Set modal title
    DOMElements.productModalTitle.textContent = 'Edit Product';
    DOMElements.productIdDisplay.textContent = `#${productId}`;

    // Populate form
    DOMElements.productName.value = product.name;
    DOMElements.productCategory.value = product.category;
    DOMElements.productPrice.value = product.price.toString();
    DOMElements.productRating.value = product.rating.toString();
    DOMElements.productImage.value = product.image;
    DOMElements.productSoldOut.checked = product.soldOut || false;
    DOMElements.productId.value = productId.toString();

    // Show image preview
    DOMElements.imagePreview.innerHTML = `<img src="${product.image}" alt="${product.name}">`;

    // Show delete button
    DOMElements.deleteProductBtn.style.display = 'inline-block';
  } else {
    // Add new product
    DOMElements.productModalTitle.textContent = 'Add New Product';
    DOMElements.productIdDisplay.textContent = '';

    // Generate a new product ID
    const newId = products.length > 0 ? Math.max(...products.map(p => p.id)) + 1 : 1;
    DOMElements.productId.value = newId.toString();

    // Hide delete button
    DOMElements.deleteProductBtn.style.display = 'none';
  }

  // Show modal
  DOMElements.productModal.classList.add('active');
  DOMElements.modalOverlay.classList.add('active');
}

// Close product modal
function closeProductModal(): void {
  DOMElements.productModal.classList.remove('active');
  DOMElements.modalOverlay.classList.remove('active');
  currentProductId = null;
}

// Handle product form submission
function handleProductFormSubmit(e: Event): void {
  e.preventDefault();

  const productId = parseInt(DOMElements.productId.value, 10);
  const productIndex = products.findIndex(p => p.id === productId);

  const productData: Product = {
    id: productId,
    name: DOMElements.productName.value,
    category: DOMElements.productCategory.value,
    price: parseFloat(DOMElements.productPrice.value),
    rating: parseInt(DOMElements.productRating.value, 10),
    image: DOMElements.productImage.value,
    soldOut: DOMElements.productSoldOut.checked
  };

  if (productIndex === -1) {
    // Add new product
    products.push(productData);
  } else {
    // Update existing product
    products[productIndex] = productData;
  }

  // Save products to localStorage
  localStorage.setItem('products', JSON.stringify(products));
  localStorage.setItem('adminProducts', JSON.stringify(products));

  // Re-render products table
  renderProducts();

  // Close modal
  closeProductModal();
}

// Handle product deletion
function handleProductDelete(): void {
  if (currentProductId === null) return;

  if (confirm(`Are you sure you want to delete product #${currentProductId}?`)) {
    // Remove product
    products = products.filter(p => p.id !== currentProductId);

    // Save updated products to localStorage
    localStorage.setItem('products', JSON.stringify(products));
    localStorage.setItem('adminProducts', JSON.stringify(products));

    // Re-render products table
    renderProducts();

    // Close modal
    closeProductModal();
  }
}

// Update image preview when URL is entered
function updateImagePreview(): void {
  const imageUrl = DOMElements.productImage.value.trim();
  if (imageUrl) {
    DOMElements.imagePreview.innerHTML = `<img src="${imageUrl}" alt="Preview">`;
  } else {
    DOMElements.imagePreview.innerHTML = '<div class="empty-image">No Image Selected</div>';
  }
}

// Initialize event listeners for the order modal
function initOrderModalEvents(): void {
  // Close modal
  DOMElements.closeOrderModal.addEventListener('click', closeOrderModal);

  // Form submission
  DOMElements.orderForm.addEventListener('submit', handleOrderFormSubmit);
}

// Initialize event listeners for the reply modal
function initReplyModalEvents(): void {
  // Close modal
  DOMElements.closeReplyModal.addEventListener('click', closeReplyModal);

  // Mark as read button
  DOMElements.markReadBtn.addEventListener('click', markMessageAsRead);

  // Form submission
  DOMElements.replyForm.addEventListener('submit', handleReplyFormSubmit);
}

// Initialize event listeners for the product modal
function initProductModalEvents(): void {
  // Close modal
  DOMElements.closeProductModal.addEventListener('click', closeProductModal);

  // Form submission
  DOMElements.productForm.addEventListener('submit', handleProductFormSubmit);

  // Delete button
  DOMElements.deleteProductBtn.addEventListener('click', handleProductDelete);

  // Image preview on input change
  DOMElements.productImage.addEventListener('input', updateImagePreview);
}

// Initialize all event listeners
function initEventListeners(): void {
  // Navigation links
  DOMElements.navLinks.forEach(link => {
    link.addEventListener('click', (e) => {
      e.preventDefault();

      const target = e.currentTarget as HTMLElement;
      const pageId = target.getAttribute('data-page');

      if (!pageId) return;

      // Update active link
      DOMElements.navLinks.forEach(link => link.parentElement?.classList.remove('active'));
      target.parentElement?.classList.add('active');

      // Hide all pages and show the target page
      DOMElements.adminPages.forEach(page => page.classList.remove('active'));
      document.getElementById(pageId)?.classList.add('active');

      // Update page title
      const pageTitle = target.textContent?.trim() || '';
      DOMElements.pageTitle.textContent = pageTitle.includes('Support')
        ? 'Support Messages'
        : pageTitle.includes('Product')
          ? 'Product Management'
          : 'Orders Management';
    });
  });

  // Search button
  DOMElements.searchBtn.addEventListener('click', () => {
    const searchTerm = DOMElements.orderSearch.value.trim().toLowerCase();

    if (searchTerm) {
      const filteredOrders = orders.filter(order =>
        (order.orderId?.toLowerCase() || order.id?.toLowerCase() || '').includes(searchTerm) ||
        `${order.firstName} ${order.lastName}`.toLowerCase().includes(searchTerm) ||
        order.email.toLowerCase().includes(searchTerm)
      );

      renderOrders(filteredOrders);
    } else {
      renderOrders(orders);
    }
  });

  // Add product button
  DOMElements.addProductBtn.addEventListener('click', () => openProductModal());

  // Logout link
  DOMElements.logoutLink.addEventListener('click', (e) => {
    e.preventDefault();
    localStorage.removeItem('isAdminLoggedIn');
    window.location.href = './admin-login.html';
  });

  // Init modal event listeners
  initOrderModalEvents();
  initReplyModalEvents();
  initProductModalEvents();
}

// Initialization function
function init(): void {
  // Check if admin is logged in
  const isLoggedIn = localStorage.getItem('isAdminLoggedIn') === 'true';
  if (!isLoggedIn) {
    window.location.href = './admin-login.html';
    return;
  }

  // Load data
  loadOrders();
  loadSupportMessages();
  loadProducts();

  // Init event listeners
  initEventListeners();
}

// Initialize the admin panel
document.addEventListener('DOMContentLoaded', init);
