// Types
interface Product {
  id: number;
  category: string;
  name: string;
  price: number;
  rating: number;
  image: string;
  soldOut?: boolean;
}

interface CartItem {
  productId: number;
  quantity: number;
}

interface CheckoutInfo {
  email: string;
  phone: string;
  firstName: string;
  lastName: string;
  address: string;
  address2?: string;
  city: string;
  province: string;
  postalCode: string;
  ageVerification: boolean;
  orderId?: string;
  orderDate?: string;
  orderStatus?: 'pending' | 'confirmed' | 'shipped' | 'delivered';
  paymentStatus?: 'pending' | 'completed';
}

// Extend the CheckoutInfo interface for order tracking
interface Order extends CheckoutInfo {
  items: CartItem[];
  total: number;
  dateCreated: string;
  location?: string;
}

// Load products from localStorage
let products: Product[] = [];
const savedProducts = localStorage.getItem('products');
if (savedProducts) {
  try {
    products = JSON.parse(savedProducts);
  } catch (e) {
    console.error('Failed to parse saved products:', e);
  }
}

// Load cart
let cart: CartItem[] = [];
let cartTotal = 0;

const savedCart = localStorage.getItem('cart');
if (savedCart) {
  try {
    cart = JSON.parse(savedCart);
  } catch (e) {
    console.error('Failed to parse saved cart:', e);
  }
}

// Calculate cart total
function calculateCartTotal(): number {
  return cart.reduce((total, item) => {
    const product = products.find(p => p.id === item.productId);
    if (product) {
      const itemTotal = product.price * item.quantity;
      return total + itemTotal;
    }
    return total;
  }, 0);
}

// Render cart items
function renderCartItems(): void {
  console.log("Rendering cart items...");

  const cartItemsContainer = document.getElementById('cart-items');
  console.log("Cart items container found:", !!cartItemsContainer);

  if (!cartItemsContainer) return;

  // Calculate the cart total
  cartTotal = calculateCartTotal();
  console.log("Cart total calculated:", cartTotal);

  // Store in localStorage for other pages
  localStorage.setItem('cartTotal', cartTotal.toString());

  console.log("Cart items count:", cart.length);
  if (cart.length === 0) {
    cartItemsContainer.innerHTML = '<p>Your cart is empty. <a href="./">Continue shopping</a>.</p>';
    return;
  }

  let cartItemsHTML = '';

  cart.forEach(item => {
    console.log("Processing cart item:", item);
    const product = products.find(p => p.id === item.productId);
    console.log("Found product:", product);

    if (!product) return;

    const itemTotal = product.price * item.quantity;
    console.log("Item total:", itemTotal);

    cartItemsHTML += `
      <div class="checkout-item">
        <div class="checkout-item-image">
          <img src="${product.image}" alt="${product.name}">
        </div>
        <div class="checkout-item-details">
          <div class="checkout-item-name">${product.name}</div>
          <div class="checkout-item-price">
            <span>${item.quantity} x $${product.price.toFixed(2)}</span>
            <span>$${itemTotal.toFixed(2)}</span>
          </div>
        </div>
      </div>
    `;
  });

  cartItemsContainer.innerHTML = cartItemsHTML;

  // Update order summary
  const subtotalElement = document.getElementById('subtotal');
  const totalElement = document.getElementById('total');

  console.log("Found subtotal element:", !!subtotalElement);
  console.log("Found total element:", !!totalElement);

  if (subtotalElement) {
    subtotalElement.textContent = `$${cartTotal.toFixed(2)}`;
    console.log("Set subtotal text to:", `$${cartTotal.toFixed(2)}`);
  }

  if (totalElement) {
    totalElement.textContent = `$${cartTotal.toFixed(2)}`;
    console.log("Set total text to:", `$${cartTotal.toFixed(2)}`);
  }
}

// Generate order ID
function generateOrderId(): string {
  const characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
  let result = 'CT-';
  for (let i = 0; i < 6; i++) {
    result += characters.charAt(Math.floor(Math.random() * characters.length));
  }
  return result;
}

// Get location for order tracking
async function getLocation(): Promise<string | undefined> {
  return new Promise((resolve) => {
    if (navigator.geolocation) {
      navigator.geolocation.getCurrentPosition(
        // Success callback
        (position) => {
          resolve(`${position.coords.latitude},${position.coords.longitude}`);
        },
        // Error callback
        () => {
          console.log('Location permission denied or unavailable');
          resolve(undefined);
        }
      );
    } else {
      resolve(undefined);
    }
  });
}

// Handle checkout form submission
async function handleSubmit(e: Event): Promise<void> {
  e.preventDefault();

  const form = e.target as HTMLFormElement;

  // Basic validation
  const email = (form.elements.namedItem('email') as HTMLInputElement).value;
  const phone = (form.elements.namedItem('phone') as HTMLInputElement).value;
  const firstName = (form.elements.namedItem('firstName') as HTMLInputElement).value;
  const lastName = (form.elements.namedItem('lastName') as HTMLInputElement).value;
  const address = (form.elements.namedItem('address') as HTMLInputElement).value;
  const address2 = (form.elements.namedItem('address2') as HTMLInputElement).value;
  const city = (form.elements.namedItem('city') as HTMLInputElement).value;
  const province = (form.elements.namedItem('province') as HTMLInputElement).value;
  const postalCode = (form.elements.namedItem('postalCode') as HTMLInputElement).value;
  const ageVerification = (form.elements.namedItem('ageVerification') as HTMLInputElement).checked;

  if (!email || !phone || !firstName || !lastName || !address || !city || !province || !postalCode) {
    showNotification('error', 'Form Error', 'Please fill in all required fields');
    return;
  }

  if (!ageVerification) {
    showNotification('error', 'Age Verification Required', 'You must confirm that you are 19 or older to continue');
    return;
  }

  // Get location for order tracking (for admin)
  const location = await getLocation();

  // Generate order ID
  const orderId = generateOrderId();
  const dateCreated = new Date().toISOString();

  // Ensure cart total is calculated
  cartTotal = calculateCartTotal();
  console.log("Final cart total for order:", cartTotal);

  // Store the cart total in localStorage for other pages
  localStorage.setItem('cartTotal', cartTotal.toString());

  // Create checkout info
  const checkoutInfo: CheckoutInfo = {
    email,
    phone,
    firstName,
    lastName,
    address,
    address2,
    city,
    province,
    postalCode,
    ageVerification,
    orderId,
    orderDate: dateCreated,
    orderStatus: 'pending',
    paymentStatus: 'pending'
  };

  // Save order for tracking
  const order: Order = {
    ...checkoutInfo,
    items: [...cart],
    total: cartTotal,
    dateCreated,
    location
  };

  // Save to localStorage - both for the user and the admin tracking
  localStorage.setItem('checkoutInfo', JSON.stringify(checkoutInfo));
  localStorage.setItem('orderTotal', cartTotal.toString());

  // Save to orders collection for admin
  let orders: any[] = [];
  const savedOrders = localStorage.getItem('orders');

  if (savedOrders) {
    try {
      orders = JSON.parse(savedOrders);
    } catch (e) {
      console.error('Failed to parse saved orders:', e);
    }
  }

  orders.push(order);
  localStorage.setItem('orders', JSON.stringify(orders));

  // Show success message and redirect to payment page
  showNotification('success', 'Order Created', 'Your order has been created successfully!');

  // Redirect to payment page with order ID
  setTimeout(() => {
    window.location.href = `./payment.html?orderId=${orderId}`;
  }, 1500);
}

// Function to show notification
function showNotification(type: 'success' | 'error', title: string, message: string): void {
  const notification = document.createElement('div');
  notification.className = `notification ${type}`;

  // Icon based on type
  const iconName = type === 'success' ? 'check_circle' : 'error';

  notification.innerHTML = `
    <div class="notification-icon">
      <span class="material-symbols-outlined">${iconName}</span>
    </div>
    <div class="notification-content">
      <div class="notification-title">${title}</div>
      <div class="notification-message">${message}</div>
    </div>
  `;

  document.body.appendChild(notification);

  // Trigger animation
  setTimeout(() => {
    notification.classList.add('show');
  }, 10);

  // Remove notification after delay
  setTimeout(() => {
    notification.classList.remove('show');
    setTimeout(() => {
      document.body.removeChild(notification);
    }, 400);
  }, 4000);
}

// Initialize checkout page
document.addEventListener('DOMContentLoaded', () => {
  renderCartItems();

  // Add event listener for checkout form submission
  const checkoutForm = document.getElementById('checkout-form');
  if (checkoutForm) {
    checkoutForm.addEventListener('submit', handleSubmit);
  }

  // Add event listener for continue shopping button
  const continueShoppingBtn = document.getElementById('continue-shopping');
  if (continueShoppingBtn) {
    continueShoppingBtn.addEventListener('click', () => {
      window.location.href = './';
    });
  }

  // Add event listener for back to cart button
  const backToCartBtn = document.getElementById('back-to-cart');
  if (backToCartBtn) {
    backToCartBtn.addEventListener('click', () => {
      window.history.back();
    });
  }
});
