// Types
interface Product {
  id: number;
  category: string;
  name: string;
  price: number;
  rating: number;
  image: string;
}

interface CartItem {
  productId: number;
  quantity: number;
}

interface CheckoutInfo {
  email: string;
  phone: string;
  firstName: string;
  lastName: string;
  address: string;
  address2?: string;
  city: string;
  province: string;
  postalCode: string;
  ageVerification: boolean;
  orderId?: string;
  orderDate?: string;
  orderStatus?: 'pending' | 'confirmed' | 'shipped' | 'delivered';
  paymentStatus?: 'pending' | 'completed';
}

interface SupportMessage {
  orderNumber: string;
  message: string;
  createdAt: string;
  isRead: boolean;
}

// Product data
const products: Product[] = [
  {
    id: 1,
    category: 'Canadian Classics',
    name: 'Canadian Classics Original',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/674305779.jpeg'
  },
  {
    id: 2,
    category: 'Canadian Classics',
    name: 'Canadian Classics Silver',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/3000929280.jpeg'
  },
  {
    id: 3,
    category: 'Canadian Classics',
    name: 'Canadian Full Flavour',
    price: 50.00,
    rating: 4,
    image: 'https://ext.same-assets.com/698571986/2061452602.jpeg'
  },
  {
    id: 4,
    category: 'Canadian Classics',
    name: 'Canadian Lights Cigarettes',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/4081112461.jpeg'
  },
  {
    id: 5,
    category: 'Canadian Classics',
    name: 'Canadian Menthol',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/1829912013.jpeg'
  },
  {
    id: 6,
    category: 'Canadian Classics',
    name: 'Canadian Premium Original Cigarettes',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/174693145.jpeg'
  },
  {
    id: 7,
    category: 'Canadian Classics',
    name: 'Canadian Ultra Light Cigarettes',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/2524349341.jpeg'
  }
];

// Initialize variables
let cart: CartItem[] = [];
let checkoutInfo: CheckoutInfo | null = null;

// Function to render order items
function renderOrderItems(): void {
  const orderItemsContainer = document.getElementById('order-items');
  if (!orderItemsContainer) return;

  if (cart.length === 0) {
    orderItemsContainer.innerHTML = '<p>No items in order</p>';
    return;
  }

  let orderItemsHTML = '';
  let calculatedTotal = 0;

  cart.forEach(item => {
    const product = products.find(p => p.id === item.productId);
    if (!product) return;

    const itemTotal = product.price * item.quantity;
    calculatedTotal += itemTotal;

    orderItemsHTML += `
      <div class="summary-item">
        <div class="summary-item-image">
          <img src="${product.image}" alt="${product.name}">
        </div>
        <div class="summary-item-details">
          <div class="summary-item-title">${product.name}</div>
          <div class="summary-item-price">$${product.price.toFixed(2)}</div>
        </div>
        <div class="summary-item-quantity">Qty: ${item.quantity}</div>
        <div class="summary-item-total">$${itemTotal.toFixed(2)}</div>
      </div>
    `;
  });

  orderItemsContainer.innerHTML = orderItemsHTML;

  // Get order total from localStorage if available
  let finalTotal = calculatedTotal;
  const savedOrderTotal = localStorage.getItem('orderTotal');
  if (savedOrderTotal) {
    try {
      const parsedTotal = parseFloat(savedOrderTotal);
      if (!isNaN(parsedTotal)) {
        finalTotal = parsedTotal;
      }
    } catch (e) {
      console.error('Failed to parse saved order total:', e);
    }
  }

  // Update totals
  const subtotalElement = document.getElementById('subtotal');
  const totalElement = document.getElementById('total');

  if (subtotalElement) {
    subtotalElement.textContent = `$${finalTotal.toFixed(2)}`;
  }

  if (totalElement) {
    totalElement.textContent = `$${finalTotal.toFixed(2)}`;
  }
}

// Function to render shipping address
function renderShippingAddress(): void {
  const addressContainer = document.getElementById('shipping-address');
  if (!addressContainer || !checkoutInfo) return;

  addressContainer.innerHTML = `
    ${checkoutInfo.firstName} ${checkoutInfo.lastName}<br>
    ${checkoutInfo.address}<br>
    ${checkoutInfo.address2 ? checkoutInfo.address2 + '<br>' : ''}
    ${checkoutInfo.city}, ${checkoutInfo.province} ${checkoutInfo.postalCode}<br>
    <br>
    Email: ${checkoutInfo.email}<br>
    Phone: ${checkoutInfo.phone}
  `;
}

// Function to populate order information
function populateOrderInfo(): void {
  if (!checkoutInfo) return;

  const orderNumberElement = document.getElementById('order-number');
  const orderDateElement = document.getElementById('order-date');
  const orderReceivedDateElement = document.getElementById('order-received-date');

  if (orderNumberElement && checkoutInfo.orderId) {
    orderNumberElement.textContent = checkoutInfo.orderId;
  }

  if (orderDateElement && checkoutInfo.orderDate) {
    orderDateElement.textContent = checkoutInfo.orderDate;
  }

  if (orderReceivedDateElement && checkoutInfo.orderDate) {
    orderReceivedDateElement.textContent = checkoutInfo.orderDate;
  }

  // Populate support form order number
  const supportOrderNumberInput = document.getElementById('support-order-number') as HTMLInputElement;
  if (supportOrderNumberInput && checkoutInfo.orderId) {
    supportOrderNumberInput.value = checkoutInfo.orderId;
  }
}

// Function to handle modal
function setupModal(): void {
  const supportButton = document.getElementById('support-button');
  const closeModalButton = document.getElementById('close-modal');
  const modalOverlay = document.getElementById('modal-overlay');
  const supportModal = document.getElementById('support-modal');
  const supportForm = document.getElementById('support-form');

  if (!supportButton || !closeModalButton || !modalOverlay || !supportModal || !supportForm) return;

  // Close modal function that can be used within this scope
  function closeModal(): void {
    if (modalOverlay && supportModal) {
      modalOverlay.classList.remove('show');
      supportModal.classList.remove('show');
    }
  }

  // Open modal
  supportButton.addEventListener('click', () => {
    modalOverlay.classList.add('show');
    supportModal.classList.add('show');
  });

  // Close modal
  closeModalButton.addEventListener('click', closeModal);
  modalOverlay.addEventListener('click', closeModal);

  // Handle form submission
  supportForm.addEventListener('submit', (e: Event) => {
    e.preventDefault();

    const form = e.target as HTMLFormElement;
    const orderNumber = (form.elements.namedItem('orderNumber') as HTMLInputElement).value;
    const message = (form.elements.namedItem('message') as HTMLTextAreaElement).value;

    if (!orderNumber || !message) return;

    // Create support message
    const supportMessage: SupportMessage = {
      orderNumber,
      message,
      createdAt: new Date().toISOString(),
      isRead: false
    };

    // Get existing messages or initialize new array
    let supportMessages: SupportMessage[] = [];
    const savedMessages = localStorage.getItem('supportMessages');

    if (savedMessages) {
      try {
        supportMessages = JSON.parse(savedMessages);
      } catch (e) {
        console.error('Failed to parse saved support messages:', e);
      }
    }

    // Add new message
    supportMessages.push(supportMessage);

    // Save to localStorage
    localStorage.setItem('supportMessages', JSON.stringify(supportMessages));

    // Close modal and show success notification
    closeModal();
    showNotification('Your message has been sent! We will get back to you soon.');

    // Reset form
    form.reset();
  });
}

// Function to show notification
function showNotification(message: string): void {
  const notification = document.createElement('div');
  notification.className = 'notification';
  notification.textContent = message;

  document.body.appendChild(notification);

  // Trigger animation
  setTimeout(() => {
    notification.classList.add('show');
  }, 10);

  // Remove notification after delay
  setTimeout(() => {
    notification.classList.remove('show');
    setTimeout(() => {
      document.body.removeChild(notification);
    }, 300);
  }, 3000);
}

// Clear cart on confirmation page load
function clearCart(): void {
  // Don't clear order information, but clear the actual cart
  localStorage.removeItem('cart');
}

// Initialize confirmation page
document.addEventListener('DOMContentLoaded', () => {
  // Load cart from localStorage
  const savedCart = localStorage.getItem('cart');
  if (savedCart) {
    try {
      cart = JSON.parse(savedCart);
    } catch (e) {
      console.error('Failed to parse saved cart:', e);
      cart = [];
    }
  }

  // Load checkout info from localStorage
  const savedCheckoutInfo = localStorage.getItem('checkoutInfo');
  if (savedCheckoutInfo) {
    try {
      checkoutInfo = JSON.parse(savedCheckoutInfo);
    } catch (e) {
      console.error('Failed to parse saved checkout info:', e);
      window.location.href = './';
      return;
    }
  } else {
    // No checkout info, redirect to home
    window.location.href = './';
    return;
  }

  // Render order items
  renderOrderItems();

  // Render shipping address
  renderShippingAddress();

  // Populate order information
  populateOrderInfo();

  // Set up support modal
  setupModal();

  // Clear cart (but keep order info)
  clearCart();
});
