// Define the product interface
interface Product {
  id: number;
  category: string;
  name: string;
  price: number;
  rating: number;
  image: string;
  soldOut?: boolean;
}

// Define the CartItem interface
interface CartItem {
  productId: number;
  quantity: number;
}

// Product data
const defaultProducts: Product[] = [
  {
    id: 1,
    category: 'Canada Tobacco',
    name: 'Canada Tobacco Original',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/674305779.jpeg'
  },
  {
    id: 2,
    category: 'Canada Tobacco',
    name: 'Canada Tobacco Silver',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/3000929280.jpeg'
  },
  {
    id: 3,
    category: 'Canada Tobacco',
    name: 'Canada Full Flavour',
    price: 50.00,
    rating: 4,
    image: 'https://ext.same-assets.com/698571986/2061452602.jpeg'
  },
  {
    id: 4,
    category: 'Canada Tobacco',
    name: 'Canada Lights Cigarettes',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/4081112461.jpeg'
  },
  {
    id: 5,
    category: 'Canada Tobacco',
    name: 'Canada Menthol',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/1829912013.jpeg'
  },
  {
    id: 6,
    category: 'Canada Tobacco',
    name: 'Canada Premium Original Cigarettes',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/174693145.jpeg'
  },
  {
    id: 7,
    category: 'Canada Tobacco',
    name: 'Canada Ultra Light Cigarettes',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/2524349341.jpeg'
  }
];

// Load products from localStorage if available, otherwise use default products
let products: Product[] = [];
const savedProducts = localStorage.getItem('products');
if (savedProducts) {
  try {
    products = JSON.parse(savedProducts);
  } catch (e) {
    console.error('Failed to parse saved products:', e);
    products = defaultProducts;
  }
} else {
  products = defaultProducts;
  // Save default products to localStorage
  localStorage.setItem('products', JSON.stringify(products));
}

// Initialize cart
let cart: CartItem[] = [];
let cartTotal = 0;
let miniCartVisible = false;

// Function to update cart total
function updateCartTotal(): void {
  cartTotal = cart.reduce((total, item) => {
    const product = products.find(p => p.id === item.productId);
    if (product) {
      const itemTotal = product.price * item.quantity;
      return total + itemTotal;
    }
    return total;
  }, 0);

  const cartTotalElement = document.getElementById('cart-total');
  if (cartTotalElement) {
    cartTotalElement.textContent = `$${cartTotal.toFixed(2)}`;
  }

  const cartCountElement = document.getElementById('cart-count');
  if (cartCountElement) {
    const itemCount = cart.reduce((count, item) => count + item.quantity, 0);
    cartCountElement.textContent = itemCount.toString();
  }

  // Enable or disable checkout button based on cart contents
  const checkoutButton = document.getElementById('checkout-button');
  if (checkoutButton) {
    if (cart.length === 0) {
      checkoutButton.setAttribute('disabled', 'true');
      checkoutButton.classList.add('disabled');
    } else {
      checkoutButton.removeAttribute('disabled');
      checkoutButton.classList.remove('disabled');
    }
  }

  // Save cart total to localStorage
  localStorage.setItem('cartTotal', cartTotal.toString());

  // Save cart to localStorage
  localStorage.setItem('cart', JSON.stringify(cart));
}

// Function to generate stars based on rating
function generateStars(rating: number): string {
  let stars = '';
  for (let i = 0; i < 5; i++) {
    if (i < rating) {
      stars += '<span class="star">★</span>'; // Filled star
    } else {
      stars += '<span class="star" style="color: #ccc">★</span>'; // Empty star
    }
  }
  return stars;
}

// Function to render products
function renderProducts(productList: Product[]): void {
  const productGrid = document.querySelector('.product-grid');
  if (!productGrid) return;

  // Filter out sold out products
  const availableProducts = productList.filter(product => !product.soldOut);

  productGrid.innerHTML = availableProducts.map(product => `
    <div class="product-card" data-id="${product.id}">
      <div class="product-image">
        <img src="${product.image}" alt="${product.name}">
      </div>
      <div class="product-details">
        <div class="product-category">${product.category}</div>
        <h3 class="product-title">${product.name}</h3>
        <div class="rating">
          ${generateStars(product.rating)}
        </div>
        <div class="product-price">$${product.price.toFixed(2)}</div>
        <div class="product-actions">
          <div class="quantity-control">
            <button class="quantity-btn decrease" data-id="${product.id}">-</button>
            <input type="number" min="1" value="1" class="quantity-input" data-id="${product.id}">
            <button class="quantity-btn increase" data-id="${product.id}">+</button>
          </div>
          <button class="add-to-cart" data-id="${product.id}">
            <span class="material-symbols-outlined">shopping_cart</span>
            Add to cart
          </button>
        </div>
      </div>
    </div>
  `).join('');

  // Add event listeners for quantity buttons and add to cart
  document.querySelectorAll('.quantity-btn').forEach(button => {
    button.addEventListener('click', handleQuantityChange);
  });

  document.querySelectorAll('.quantity-input').forEach(input => {
    input.addEventListener('change', handleQuantityInputChange);
  });

  document.querySelectorAll('.add-to-cart').forEach(button => {
    button.addEventListener('click', handleAddToCart);
  });
}

// Handle quantity change
function handleQuantityChange(e: Event): void {
  const button = e.currentTarget as HTMLElement;
  const productId = parseInt(button.getAttribute('data-id') || '0');
  const isIncrease = button.classList.contains('increase');
  const input = document.querySelector(`.quantity-input[data-id="${productId}"]`) as HTMLInputElement;

  if (input) {
    let quantity = parseInt(input.value) || 1;
    if (isIncrease) {
      quantity += 1;
    } else {
      quantity = Math.max(1, quantity - 1);
    }
    input.value = quantity.toString();
  }
}

// Handle quantity input change
function handleQuantityInputChange(e: Event): void {
  const input = e.currentTarget as HTMLInputElement;
  let quantity = parseInt(input.value) || 1;

  // Ensure quantity is at least 1
  if (quantity < 1) {
    quantity = 1;
    input.value = '1';
  }
}

// Handle add to cart button click
function handleAddToCart(e: Event): void {
  const button = e.currentTarget as HTMLElement;
  const productId = parseInt(button.getAttribute('data-id') || '0');
  const product = products.find(p => p.id === productId);

  if (!product) return;

  // Get quantity from input
  const quantityInput = document.querySelector(`.quantity-input[data-id="${productId}"]`) as HTMLInputElement;
  const quantity = quantityInput ? parseInt(quantityInput.value) || 1 : 1;

  // Check if product is already in cart
  const existingItemIndex = cart.findIndex(item => item.productId === productId);

  if (existingItemIndex !== -1) {
    // Update quantity of existing item
    cart[existingItemIndex].quantity += quantity;
  } else {
    // Add new item to cart
    cart.push({ productId, quantity });
  }

  // Reset quantity input
  if (quantityInput) {
    quantityInput.value = '1';
  }

  updateCartTotal();
  renderMiniCart();
  showNotification('success', 'Added to Cart', `Added ${quantity} x ${product.name} to your cart`);
}

// Function to remove item from cart
function removeFromCart(productId: number): void {
  const itemIndex = cart.findIndex(item => item.productId === productId);

  if (itemIndex !== -1) {
    const product = products.find(p => p.id === productId);
    cart.splice(itemIndex, 1);
    updateCartTotal();
    renderMiniCart();
    if (product) {
      showNotification('success', 'Item Removed', `${product.name} has been removed from your cart`);
    }
  }
}

// Function to update item quantity in cart
function updateCartItemQuantity(productId: number, quantity: number): void {
  const itemIndex = cart.findIndex(item => item.productId === productId);

  if (itemIndex !== -1 && quantity > 0) {
    cart[itemIndex].quantity = quantity;
    updateCartTotal();
    renderMiniCart();
  } else if (itemIndex !== -1 && quantity <= 0) {
    removeFromCart(productId);
  }
}

// Function to render mini cart
function renderMiniCart(): void {
  const miniCartElement = document.getElementById('mini-cart');

  if (!miniCartElement) {
    // Create mini cart if it doesn't exist
    createMiniCart();
    return;
  }

  const miniCartItems = document.getElementById('mini-cart-items');
  if (!miniCartItems) return;

  if (cart.length === 0) {
    miniCartItems.innerHTML = `
      <div class="mini-cart-empty">
        Your cart is empty
      </div>
    `;
  } else {
    miniCartItems.innerHTML = cart.map(item => {
      const product = products.find(p => p.id === item.productId);
      if (!product) return '';

      return `
        <div class="cart-item">
          <div class="cart-item-image">
            <img src="${product.image}" alt="${product.name}">
          </div>
          <div class="cart-item-details">
            <div class="cart-item-name">${product.name}</div>
            <div class="cart-item-price">
              <div class="cart-item-quantity">
                <button class="cart-quantity-update" data-action="decrease" data-id="${product.id}">-</button>
                <span>${item.quantity}</span>
                <button class="cart-quantity-update" data-action="increase" data-id="${product.id}">+</button>
              </div>
              <div>$${(product.price * item.quantity).toFixed(2)}</div>
            </div>
            <button class="cart-item-remove" data-id="${product.id}">Remove</button>
          </div>
        </div>
      `;
    }).join('');
  }

  // Update subtotal
  const subtotalElement = document.getElementById('mini-cart-subtotal-value');
  if (subtotalElement) {
    subtotalElement.textContent = `$${cartTotal.toFixed(2)}`;
  }

  // Add event listeners to cart item buttons
  document.querySelectorAll('.cart-quantity-update').forEach(button => {
    button.addEventListener('click', handleCartQuantityUpdate);
  });

  document.querySelectorAll('.cart-item-remove').forEach(button => {
    button.addEventListener('click', handleRemoveFromCart);
  });
}

// Create mini cart structure
function createMiniCart(): void {
  const miniCart = document.createElement('div');
  miniCart.id = 'mini-cart';
  miniCart.className = 'mini-cart';

  miniCart.innerHTML = `
    <div class="mini-cart-header">
      <div class="mini-cart-title">
        <span class="material-symbols-outlined">shopping_cart</span>
        Your Cart
      </div>
      <button class="mini-cart-close">
        <span class="material-symbols-outlined">close</span>
      </button>
    </div>
    <div id="mini-cart-items" class="mini-cart-items"></div>
    <div class="mini-cart-footer">
      <div class="mini-cart-subtotal">
        <span>Subtotal:</span>
        <span id="mini-cart-subtotal-value">$0.00</span>
      </div>
      <div class="mini-cart-actions">
        <button id="view-cart-btn" class="button button-outline">View Cart</button>
        <button id="checkout-mini-cart-btn" class="button button-primary">Checkout</button>
      </div>
    </div>
  `;

  document.body.appendChild(miniCart);

  // Add event listeners
  const closeBtn = miniCart.querySelector('.mini-cart-close');
  if (closeBtn) {
    closeBtn.addEventListener('click', toggleMiniCart);
  }

  const checkoutBtn = document.getElementById('checkout-mini-cart-btn');
  if (checkoutBtn) {
    checkoutBtn.addEventListener('click', () => {
      window.location.href = './checkout.html';
    });
  }

  const viewCartBtn = document.getElementById('view-cart-btn');
  if (viewCartBtn) {
    viewCartBtn.addEventListener('click', () => {
      // This would normally go to a cart page, but for now use checkout
      window.location.href = './checkout.html';
    });
  }

  renderMiniCart();
}

// Toggle mini cart visibility
function toggleMiniCart(): void {
  const miniCart = document.getElementById('mini-cart');
  if (!miniCart) {
    createMiniCart();
    return;
  }

  miniCartVisible = !miniCartVisible;

  if (miniCartVisible) {
    miniCart.classList.add('show');
  } else {
    miniCart.classList.remove('show');
  }
}

// Handle cart quantity update
function handleCartQuantityUpdate(e: Event): void {
  const button = e.currentTarget as HTMLElement;
  const productId = parseInt(button.getAttribute('data-id') || '0');
  const action = button.getAttribute('data-action');

  const cartItem = cart.find(item => item.productId === productId);
  if (!cartItem) return;

  if (action === 'increase') {
    updateCartItemQuantity(productId, cartItem.quantity + 1);
  } else if (action === 'decrease') {
    updateCartItemQuantity(productId, cartItem.quantity - 1);
  }
}

// Handle remove from cart
function handleRemoveFromCart(e: Event): void {
  const button = e.currentTarget as HTMLElement;
  const productId = parseInt(button.getAttribute('data-id') || '0');

  removeFromCart(productId);
}

// Function to show notification
function showNotification(type: 'success' | 'error', title: string, message: string): void {
  const notification = document.createElement('div');
  notification.className = `notification ${type}`;

  // Icon based on type
  const iconName = type === 'success' ? 'check_circle' : 'error';

  notification.innerHTML = `
    <div class="notification-icon">
      <span class="material-symbols-outlined">${iconName}</span>
    </div>
    <div class="notification-content">
      <div class="notification-title">${title}</div>
      <div class="notification-message">${message}</div>
    </div>
  `;

  document.body.appendChild(notification);

  // Trigger animation
  setTimeout(() => {
    notification.classList.add('show');
  }, 10);

  // Remove notification after delay
  setTimeout(() => {
    notification.classList.remove('show');
    setTimeout(() => {
      document.body.removeChild(notification);
    }, 400);
  }, 4000);
}

// Initialize the application
document.addEventListener('DOMContentLoaded', () => {
  // Load cart from localStorage if available
  const savedCart = localStorage.getItem('cart');
  if (savedCart) {
    try {
      cart = JSON.parse(savedCart);
      updateCartTotal();
    } catch (e) {
      console.error('Failed to parse saved cart:', e);
    }
  }

  renderProducts(products);

  // Add event listener for cart info to toggle mini cart
  const cartInfo = document.querySelector('.cart-info');
  if (cartInfo) {
    cartInfo.addEventListener('click', toggleMiniCart);
  }

  // Add event listener for checkout button
  const checkoutButton = document.getElementById('checkout-button');
  if (checkoutButton) {
    checkoutButton.addEventListener('click', () => {
      window.location.href = './checkout.html';
    });
  }

  // Add event listener for track order button
  const trackOrderButton = document.getElementById('track-order-button');
  if (trackOrderButton) {
    trackOrderButton.addEventListener('click', () => {
      window.location.href = './track-order.html';
    });
  }
});
