// Types
interface Product {
  id: number;
  category: string;
  name: string;
  price: number;
  rating: number;
  image: string;
}

interface CartItem {
  productId: number;
  quantity: number;
}

interface CheckoutInfo {
  email: string;
  phone: string;
  firstName: string;
  lastName: string;
  address: string;
  address2?: string;
  city: string;
  province: string;
  postalCode: string;
  ageVerification: boolean;
  orderId?: string;
  orderDate?: string;
  orderStatus?: 'pending' | 'confirmed' | 'shipped' | 'delivered';
  paymentStatus?: 'pending' | 'completed';
}

// Product data
const products: Product[] = [
  {
    id: 1,
    category: 'Canadian Classics',
    name: 'Canadian Classics Original',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/674305779.jpeg'
  },
  {
    id: 2,
    category: 'Canadian Classics',
    name: 'Canadian Classics Silver',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/3000929280.jpeg'
  },
  {
    id: 3,
    category: 'Canadian Classics',
    name: 'Canadian Full Flavour',
    price: 50.00,
    rating: 4,
    image: 'https://ext.same-assets.com/698571986/2061452602.jpeg'
  },
  {
    id: 4,
    category: 'Canadian Classics',
    name: 'Canadian Lights Cigarettes',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/4081112461.jpeg'
  },
  {
    id: 5,
    category: 'Canadian Classics',
    name: 'Canadian Menthol',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/1829912013.jpeg'
  },
  {
    id: 6,
    category: 'Canadian Classics',
    name: 'Canadian Premium Original Cigarettes',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/174693145.jpeg'
  },
  {
    id: 7,
    category: 'Canadian Classics',
    name: 'Canadian Ultra Light Cigarettes',
    price: 50.00,
    rating: 5,
    image: 'https://ext.same-assets.com/698571986/2524349341.jpeg'
  }
];

// Initialize order variables
let cart: CartItem[] = [];
let checkoutInfo: CheckoutInfo | null = null;
let orderTotal = 0;

// Function to render cart items in the sidebar
function renderCartItems(): void {
  const cartItemsContainer = document.getElementById('cart-items');
  if (!cartItemsContainer) return;

  if (cart.length === 0) {
    cartItemsContainer.innerHTML = '<p class="empty-cart">Your cart is empty</p>';
    return;
  }

  let cartItemsHTML = '';
  let subtotal = 0;

  cart.forEach(item => {
    const product = products.find(p => p.id === item.productId);
    if (!product) return;

    const itemTotal = product.price * item.quantity;
    subtotal += itemTotal;

    cartItemsHTML += `
      <div class="cart-item">
        <div class="cart-item-image">
          <img src="${product.image}" alt="${product.name}">
        </div>
        <div class="cart-item-details">
          <div class="cart-item-title">${product.name}</div>
          <div class="cart-item-price">$${product.price.toFixed(2)}</div>
          <div class="cart-item-quantity">Quantity: ${item.quantity}</div>
          <div class="cart-item-total">Total: $${itemTotal.toFixed(2)}</div>
        </div>
      </div>
    `;
  });

  cartItemsContainer.innerHTML = cartItemsHTML;

  // Update totals
  const subtotalElement = document.getElementById('subtotal');
  const totalElement = document.getElementById('total');

  // Check for previously saved order total
  let savedTotal = subtotal;
  const savedOrderTotal = localStorage.getItem('orderTotal');
  if (savedOrderTotal) {
    try {
      const parsedTotal = parseFloat(savedOrderTotal);
      if (!isNaN(parsedTotal)) {
        savedTotal = parsedTotal;
      }
    } catch (e) {
      console.error('Failed to parse saved order total:', e);
    }
  }

  // Update orderTotal for other functions to use
  orderTotal = savedTotal;

  if (subtotalElement) {
    subtotalElement.textContent = `$${savedTotal.toFixed(2)}`;
  }

  if (totalElement) {
    totalElement.textContent = `$${savedTotal.toFixed(2)}`;
  }
}

// Function to render shipping address
function renderShippingAddress(): void {
  const addressContainer = document.getElementById('shipping-address');
  if (!addressContainer || !checkoutInfo) return;

  addressContainer.innerHTML = `
    <h3>Shipping Address</h3>
    <div class="address-details">
      ${checkoutInfo.firstName} ${checkoutInfo.lastName}<br>
      ${checkoutInfo.address}<br>
      ${checkoutInfo.address2 ? checkoutInfo.address2 + '<br>' : ''}
      ${checkoutInfo.city}, ${checkoutInfo.province} ${checkoutInfo.postalCode}<br>
      <br>
      Email: ${checkoutInfo.email}<br>
      Phone: ${checkoutInfo.phone}
    </div>
  `;
}

// Function to populate order details
function populateOrderDetails(): void {
  if (!checkoutInfo) return;

  const orderNumberElement = document.getElementById('order-number');
  const orderDateElement = document.getElementById('order-date');
  const orderTotalElement = document.getElementById('order-total');
  const transferAmountElement = document.getElementById('transfer-amount');

  if (orderNumberElement && checkoutInfo.orderId) {
    orderNumberElement.textContent = checkoutInfo.orderId;
  }

  if (orderDateElement && checkoutInfo.orderDate) {
    // Format the date nicely
    const date = new Date(checkoutInfo.orderDate);
    orderDateElement.textContent = date.toLocaleDateString() + ' ' + date.toLocaleTimeString();
  }

  // Try to get the most accurate cart total
  let currentTotal = orderTotal;

  // Check if there's a saved orderTotal
  const savedOrderTotal = localStorage.getItem('orderTotal');
  if (savedOrderTotal) {
    try {
      const parsedTotal = parseFloat(savedOrderTotal);
      if (!isNaN(parsedTotal)) {
        currentTotal = parsedTotal;
      }
    } catch (e) {
      console.error('Failed to parse saved order total:', e);
    }
  }

  // Format the total with 2 decimal places
  const formattedTotal = `$${currentTotal.toFixed(2)}`;

  if (orderTotalElement) {
    orderTotalElement.textContent = formattedTotal;
  }

  if (transferAmountElement) {
    transferAmountElement.textContent = formattedTotal;
  }
}

// Handle copy email button
function setupCopyEmailButton(): void {
  const copyButton = document.getElementById('copy-email');
  if (!copyButton) return;

  copyButton.addEventListener('click', () => {
    const email = 'davycoinc@gmail.com';

    navigator.clipboard.writeText(email)
      .then(() => {
        // Show success tooltip
        const button = copyButton as HTMLElement;
        const originalText = button.innerHTML;

        button.innerHTML = '<span class="material-symbols-outlined">check</span>';
        button.style.color = '#4caf50';

        setTimeout(() => {
          button.innerHTML = originalText;
          button.style.color = '';
        }, 2000);
      })
      .catch(err => {
        console.error('Failed to copy text: ', err);
      });
  });
}

// Handle payment confirmation
function setupPaymentConfirmation(): void {
  const confirmButton = document.getElementById('confirm-payment');
  if (!confirmButton) return;

  confirmButton.addEventListener('click', () => {
    if (!checkoutInfo) return;

    // Update order status
    checkoutInfo.paymentStatus = 'pending'; // Will be confirmed by admin

    // Store updated checkout info
    localStorage.setItem('checkoutInfo', JSON.stringify(checkoutInfo));

    // Redirect to confirmation page
    window.location.href = './confirmation.html';
  });
}

// Initialize payment page
document.addEventListener('DOMContentLoaded', () => {
  // Load cart from localStorage
  const savedCart = localStorage.getItem('cart');
  if (savedCart) {
    try {
      cart = JSON.parse(savedCart);
    } catch (e) {
      console.error('Failed to parse saved cart:', e);
      window.location.href = './';
      return;
    }
  }

  // Load checkout info from localStorage
  const savedCheckoutInfo = localStorage.getItem('checkoutInfo');
  if (savedCheckoutInfo) {
    try {
      checkoutInfo = JSON.parse(savedCheckoutInfo);
    } catch (e) {
      console.error('Failed to parse saved checkout info:', e);
      window.location.href = './checkout.html';
      return;
    }
  }

  // Load order total from localStorage
  const savedOrderTotal = localStorage.getItem('orderTotal');
  if (savedOrderTotal) {
    orderTotal = parseFloat(savedOrderTotal);
  } else {
    // Calculate order total from cart
    orderTotal = cart.reduce((total, item) => {
      const product = products.find(p => p.id === item.productId);
      return total + (product ? product.price * item.quantity : 0);
    }, 0);

    // Save it in case it wasn't saved earlier
    localStorage.setItem('orderTotal', orderTotal.toString());
  }

  // If cart is empty or no checkout info, redirect to home page
  if (cart.length === 0 || !checkoutInfo) {
    window.location.href = './';
    return;
  }

  // Render cart items
  renderCartItems();

  // Render shipping address
  renderShippingAddress();

  // Populate order details
  populateOrderDetails();

  // Setup copy email button
  setupCopyEmailButton();

  // Setup payment confirmation
  setupPaymentConfirmation();
});
