// Types
interface CheckoutInfo {
  email: string;
  phone: string;
  firstName: string;
  lastName: string;
  address: string;
  address2?: string;
  city: string;
  province: string;
  postalCode: string;
  ageVerification: boolean;
  orderId?: string;
  orderDate?: string;
  orderStatus?: 'pending' | 'confirmed' | 'shipped' | 'delivered';
  paymentStatus?: 'pending' | 'completed';
  trackingNumber?: string;
  trackingUrl?: string;
  adminNotes?: string[];
  shippingDate?: string;
  deliveryDate?: string;
}

interface CartItem {
  productId: number;
  quantity: number;
}

interface Order extends CheckoutInfo {
  items: CartItem[];
  total: number;
  dateCreated: string;
  location?: string;
  id?: string; // Added to support older order formats
}

interface SupportMessage {
  orderNumber: string;
  message: string;
  createdAt: string;
  isRead: boolean;
  customerEmail?: string;
  customerName?: string;
}

// Function to find order by order number
function findOrderByOrderId(orderId: string): Order | null {
  // Check orders collection
  const savedOrders = localStorage.getItem('orders');

  if (savedOrders) {
    try {
      const orders: Order[] = JSON.parse(savedOrders);

      // First try to find by orderId
      let order = orders.find(order => order.orderId === orderId);

      // If not found, try by id
      if (!order) {
        order = orders.find(order => order.id === orderId);
      }

      return order || null;
    } catch (e) {
      console.error('Failed to parse saved orders:', e);
    }
  }

  // Fallback to check checkoutInfo
  const savedCheckoutInfo = localStorage.getItem('checkoutInfo');

  if (savedCheckoutInfo) {
    try {
      const checkoutInfo: CheckoutInfo = JSON.parse(savedCheckoutInfo);
      if (checkoutInfo.orderId === orderId) {
        // Get cart and total from localStorage
        let cartItems: CartItem[] = [];
        const savedCart = localStorage.getItem('cart');
        if (savedCart) {
          try {
            cartItems = JSON.parse(savedCart);
          } catch (e) {
            console.error('Failed to parse saved cart:', e);
          }
        }

        let total = 0;
        const savedTotal = localStorage.getItem('orderTotal');
        if (savedTotal) {
          try {
            total = parseFloat(savedTotal);
          } catch (e) {
            console.error('Failed to parse order total:', e);
          }
        }

        // Convert CheckoutInfo to Order (partial)
        const order: Order = {
          ...checkoutInfo,
          items: cartItems,
          total: total,
          dateCreated: checkoutInfo.orderDate || new Date().toISOString()
        };
        return order;
      }
    } catch (e) {
      console.error('Failed to parse saved checkout info:', e);
    }
  }

  return null;
}

// Format date to display
function formatDate(dateString?: string): string {
  if (!dateString) return 'N/A';

  const date = new Date(dateString);
  return new Intl.DateTimeFormat('en-US', {
    year: 'numeric',
    month: 'long',
    day: 'numeric',
    hour: 'numeric',
    minute: 'numeric'
  }).format(date);
}

// Get status label class
function getStatusClass(status?: string): string {
  if (!status) return 'status-pending';

  switch (status) {
    case 'pending':
      return 'status-pending';
    case 'confirmed':
      return 'status-confirmed';
    case 'shipped':
      return 'status-shipped';
    case 'delivered':
      return 'status-delivered';
    default:
      return 'status-pending';
  }
}

// Handle order tracking form submission
function handleTrackOrder(e: Event): void {
  e.preventDefault();

  const orderNumberInput = document.getElementById('order-number') as HTMLInputElement;
  const orderNumber = orderNumberInput.value.trim();

  if (!orderNumber) {
    showNotification('error', 'Error', 'Please enter an order number');
    return;
  }

  const order = findOrderByOrderId(orderNumber);

  const orderResult = document.getElementById('order-result');
  const supportSection = document.getElementById('support-section');

  if (!orderResult) return;

  if (!order) {
    orderResult.innerHTML = `
      <div class="order-not-found">
        <div class="order-status-icon">
          <span class="material-symbols-outlined">error</span>
        </div>
        <h3>Order Not Found</h3>
        <p>We couldn't find an order with the number <strong>${orderNumber}</strong>. Please check the order number and try again.</p>
      </div>
    `;

    if (supportSection) {
      supportSection.style.display = 'block';

      // Set the order number for support form
      const supportOrderNumber = document.getElementById('support-order-number') as HTMLInputElement;
      if (supportOrderNumber) {
        supportOrderNumber.value = orderNumber;
      }
    }

    return;
  }

  // Display order details
  const statusClass = getStatusClass(order.orderStatus);
  const paymentStatusClass = order.paymentStatus === 'completed' ? 'status-delivered' : 'status-pending';

  orderResult.innerHTML = `
    <div class="order-found">
      <div class="order-header">
        <h3>Order #${order.orderId}</h3>
        <div class="order-date">Placed on ${formatDate(order.orderDate)}</div>
      </div>

      <div class="order-status-container">
        <div class="order-status-item ${order.orderStatus === 'pending' || order.orderStatus === 'confirmed' || order.orderStatus === 'shipped' || order.orderStatus === 'delivered' ? 'active' : ''}">
          <div class="status-icon">
            <span class="material-symbols-outlined">receipt</span>
          </div>
          <div class="status-label">Order Placed</div>
        </div>

        <div class="order-status-item ${order.orderStatus === 'confirmed' || order.orderStatus === 'shipped' || order.orderStatus === 'delivered' ? 'active' : ''}">
          <div class="status-icon">
            <span class="material-symbols-outlined">check_circle</span>
          </div>
          <div class="status-label">Confirmed</div>
        </div>

        <div class="order-status-item ${order.orderStatus === 'shipped' || order.orderStatus === 'delivered' ? 'active' : ''}">
          <div class="status-icon">
            <span class="material-symbols-outlined">local_shipping</span>
          </div>
          <div class="status-label">Shipped</div>
          ${order.trackingNumber ? `<div class="status-detail">Tracking: ${order.trackingNumber}</div>` : ''}
          ${order.shippingDate ? `<div class="status-detail">Date: ${formatDate(order.shippingDate)}</div>` : ''}
        </div>

        <div class="order-status-item ${order.orderStatus === 'delivered' ? 'active' : ''}">
          <div class="status-icon">
            <span class="material-symbols-outlined">home</span>
          </div>
          <div class="status-label">Delivered</div>
          ${order.deliveryDate ? `<div class="status-detail">Date: ${formatDate(order.deliveryDate)}</div>` : ''}
        </div>
      </div>

      <div class="order-details-container">
        <div class="order-details-section">
          <h4>Shipping Information</h4>
          <div class="detail-row">
            <div class="detail-label">Name:</div>
            <div class="detail-value">${order.firstName} ${order.lastName}</div>
          </div>
          <div class="detail-row">
            <div class="detail-label">Address:</div>
            <div class="detail-value">
              ${order.address}<br>
              ${order.address2 ? order.address2 + '<br>' : ''}
              ${order.city}, ${order.province} ${order.postalCode}
            </div>
          </div>
        </div>

        <div class="order-details-section">
          <h4>Order Status</h4>
          <div class="detail-row">
            <div class="detail-label">Order Status:</div>
            <div class="detail-value">
              <span class="status-label ${statusClass}">
                ${order.orderStatus ? order.orderStatus.charAt(0).toUpperCase() + order.orderStatus.slice(1) : 'Pending'}
              </span>
            </div>
          </div>
          <div class="detail-row">
            <div class="detail-label">Payment Status:</div>
            <div class="detail-value">
              <span class="status-label ${paymentStatusClass}">
                ${order.paymentStatus === 'completed' ? 'Paid' : 'Pending'}
              </span>
            </div>
          </div>
          ${order.trackingNumber ? `
          <div class="detail-row">
            <div class="detail-label">Tracking Number:</div>
            <div class="detail-value">
              ${order.trackingUrl ? `<a href="${order.trackingUrl}" target="_blank">${order.trackingNumber}</a>` : order.trackingNumber}
            </div>
          </div>
          ` : ''}
        </div>
      </div>

      ${order.adminNotes && order.adminNotes.length > 0 ? `
      <div class="order-notes">
        <h4>Notes</h4>
        <ul class="admin-notes-list">
          ${order.adminNotes.map(note => `<li>${note}</li>`).join('')}
        </ul>
      </div>
      ` : ''}
    </div>
  `;

  if (supportSection) {
    supportSection.style.display = 'block';

    // Set the order number for support form
    const supportOrderNumber = document.getElementById('support-order-number') as HTMLInputElement;
    if (supportOrderNumber) {
      supportOrderNumber.value = order.orderId || '';
    }
  }
}

// Handle support form submission
function handleSupportSubmit(e: Event): void {
  e.preventDefault();

  const form = e.target as HTMLFormElement;
  const orderNumber = (form.elements.namedItem('orderNumber') as HTMLInputElement).value;
  const message = (form.elements.namedItem('message') as HTMLTextAreaElement).value;

  if (!message.trim()) {
    showNotification('error', 'Error', 'Please enter a message');
    return;
  }

  // Get order to capture customer information
  const order = findOrderByOrderId(orderNumber);

  // Create support message
  const supportMessage: SupportMessage = {
    orderNumber,
    message,
    createdAt: new Date().toISOString(),
    isRead: false,
    customerEmail: order?.email,
    customerName: order ? `${order.firstName} ${order.lastName}` : undefined
  };

  // Get existing support messages
  let supportMessages: SupportMessage[] = [];
  const savedMessages = localStorage.getItem('supportMessages');

  if (savedMessages) {
    try {
      supportMessages = JSON.parse(savedMessages);
    } catch (e) {
      console.error('Failed to parse saved support messages:', e);
    }
  }

  // Add new message
  supportMessages.push(supportMessage);

  // Save back to localStorage
  localStorage.setItem('supportMessages', JSON.stringify(supportMessages));

  // Close modal
  closeModal();

  // Show success notification
  showNotification('success', 'Message Sent', 'Your message has been sent. We will get back to you soon.');

  // Clear form
  (form.elements.namedItem('message') as HTMLTextAreaElement).value = '';
}

// Open support modal
function openSupportModal(): void {
  const modal = document.getElementById('support-modal');
  const overlay = document.getElementById('modal-overlay');

  if (modal && overlay) {
    modal.classList.add('show');
    overlay.classList.add('show');
  }
}

// Close modal
function closeModal(): void {
  const modal = document.getElementById('support-modal');
  const overlay = document.getElementById('modal-overlay');

  if (modal && overlay) {
    modal.classList.remove('show');
    overlay.classList.remove('show');
  }
}

// Function to show notification
function showNotification(type: 'success' | 'error', title: string, message: string): void {
  const notification = document.createElement('div');
  notification.className = `notification ${type}`;

  // Icon based on type
  const iconName = type === 'success' ? 'check_circle' : 'error';

  notification.innerHTML = `
    <div class="notification-icon">
      <span class="material-symbols-outlined">${iconName}</span>
    </div>
    <div class="notification-content">
      <div class="notification-title">${title}</div>
      <div class="notification-message">${message}</div>
    </div>
  `;

  document.body.appendChild(notification);

  // Trigger animation
  setTimeout(() => {
    notification.classList.add('show');
  }, 10);

  // Remove notification after delay
  setTimeout(() => {
    notification.classList.remove('show');
    setTimeout(() => {
      document.body.removeChild(notification);
    }, 400);
  }, 4000);
}

// Initialize page
document.addEventListener('DOMContentLoaded', () => {
  // Check for order ID in URL query parameters
  const urlParams = new URLSearchParams(window.location.search);
  const orderIdParam = urlParams.get('orderId');

  if (orderIdParam) {
    // Pre-fill the order number input
    const orderNumberInput = document.getElementById('order-number') as HTMLInputElement;
    if (orderNumberInput) {
      orderNumberInput.value = orderIdParam;

      // Trigger form submission to show the order details
      const trackOrderForm = document.getElementById('track-order-form');
      if (trackOrderForm) {
        // Create and dispatch submit event
        const submitEvent = new Event('submit');
        trackOrderForm.dispatchEvent(submitEvent);
      }
    }
  }

  // Setup event listeners
  const trackOrderForm = document.getElementById('track-order-form');
  if (trackOrderForm) {
    trackOrderForm.addEventListener('submit', handleTrackOrder);
  }

  const supportButton = document.getElementById('support-button');
  if (supportButton) {
    supportButton.addEventListener('click', openSupportModal);
  }

  const closeModalButton = document.getElementById('close-modal');
  if (closeModalButton) {
    closeModalButton.addEventListener('click', closeModal);
  }

  const modalOverlay = document.getElementById('modal-overlay');
  if (modalOverlay) {
    modalOverlay.addEventListener('click', closeModal);
  }

  const supportForm = document.getElementById('support-form');
  if (supportForm) {
    supportForm.addEventListener('submit', handleSupportSubmit);
  }
});
