// Admin Panel JavaScript

// DOM Elements
const navLinks = document.querySelectorAll('.admin-nav a[data-page]');
const pageTitle = document.getElementById('page-title');
const ordersList = document.getElementById('orders-list');
const productsList = document.getElementById('products-list');
const supportList = document.getElementById('support-list');
const addProductBtn = document.getElementById('add-product-btn');
const productModal = document.getElementById('product-modal');
const orderModal = document.getElementById('order-modal');
const replyModal = document.getElementById('reply-modal');
const closeProductModalBtn = document.getElementById('close-product-modal');
const closeOrderModalBtn = document.getElementById('close-order-modal');
const closeReplyModalBtn = document.getElementById('close-reply-modal');
const productForm = document.getElementById('product-form');
const replyForm = document.getElementById('reply-form');
const updateOrderStatusBtn = document.getElementById('update-order-status');
const orderSearch = document.getElementById('order-search');
const productSearch = document.getElementById('product-search');
const supportSearch = document.getElementById('support-search');
const orderSearchBtn = document.getElementById('order-search-btn');
const productSearchBtn = document.getElementById('product-search-btn');
const supportSearchBtn = document.getElementById('support-search-btn');

// Data
let products = [];
let orders = [];
let supportMessages = [];
let currentProductId = null;
let currentOrderId = null;
let currentMessageId = null;

// Event Listeners
document.addEventListener('DOMContentLoaded', () => {
    setupNavigation();
    loadProducts();
    loadOrders();
    loadSupportMessages();
    setupEventListeners();
});

// Setup navigation
function setupNavigation() {
    navLinks.forEach(link => {
        link.addEventListener('click', (e) => {
            e.preventDefault();

            // Get page id from data attribute
            const pageId = link.getAttribute('data-page');
            if (!pageId) return;

            // Update active state
            document.querySelectorAll('.admin-nav li').forEach(item => {
                item.classList.remove('active');
            });

            link.parentElement.classList.add('active');

            // Show the selected page
            document.querySelectorAll('.admin-page').forEach(page => {
                page.classList.remove('active');
            });

            document.getElementById(pageId).classList.add('active');

            // Update page title
            if (pageTitle) {
                if (pageId === 'orders-page') {
                    pageTitle.textContent = 'Orders Management';
                } else if (pageId === 'support-page') {
                    pageTitle.textContent = 'Support Messages';
                } else if (pageId === 'products-page') {
                    pageTitle.textContent = 'Product Management';
                }
            }
        });
    });
}

// Setup event listeners
function setupEventListeners() {
    // Add product button
    if (addProductBtn) {
        addProductBtn.addEventListener('click', () => {
            openProductModal();
        });
    }

    // Close modal buttons
    if (closeProductModalBtn) {
        closeProductModalBtn.addEventListener('click', () => {
            closeProductModal();
        });
    }

    if (closeOrderModalBtn) {
        closeOrderModalBtn.addEventListener('click', () => {
            closeOrderModal();
        });
    }

    if (closeReplyModalBtn) {
        closeReplyModalBtn.addEventListener('click', () => {
            closeReplyModal();
        });
    }

    // Product form
    if (productForm) {
        productForm.addEventListener('submit', (e) => {
            e.preventDefault();
            handleProductFormSubmit();
        });
    }

    // Reply form
    if (replyForm) {
        replyForm.addEventListener('submit', (e) => {
            e.preventDefault();
            handleReplyFormSubmit();
        });
    }

    // Update order status button
    if (updateOrderStatusBtn) {
        updateOrderStatusBtn.addEventListener('click', () => {
            updateOrderStatus();
        });
    }

    // Search buttons
    if (orderSearchBtn) {
        orderSearchBtn.addEventListener('click', () => {
            filterOrders(orderSearch.value);
        });
    }

    if (productSearchBtn) {
        productSearchBtn.addEventListener('click', () => {
            filterProducts(productSearch.value);
        });
    }

    if (supportSearchBtn) {
        supportSearchBtn.addEventListener('click', () => {
            filterSupportMessages(supportSearch.value);
        });
    }

    // Search input enter key
    if (orderSearch) {
        orderSearch.addEventListener('keypress', (e) => {
            if (e.key === 'Enter') {
                filterOrders(orderSearch.value);
            }
        });
    }

    if (productSearch) {
        productSearch.addEventListener('keypress', (e) => {
            if (e.key === 'Enter') {
                filterProducts(productSearch.value);
            }
        });
    }

    if (supportSearch) {
        supportSearch.addEventListener('keypress', (e) => {
            if (e.key === 'Enter') {
                filterSupportMessages(supportSearch.value);
            }
        });
    }

    // Image URL input change for preview
    const productImageInput = document.getElementById('product-image');
    if (productImageInput) {
        productImageInput.addEventListener('input', () => {
            updateImagePreview();
        });
    }
}

// Load products from localStorage
function loadProducts() {
    const savedProducts = localStorage.getItem('products');
    if (savedProducts) {
        try {
            products = JSON.parse(savedProducts);
            renderProducts();
        } catch (e) {
            console.error('Failed to parse saved products:', e);
        }
    }
}

// Load orders from localStorage
function loadOrders() {
    const savedOrders = localStorage.getItem('orders');
    if (savedOrders) {
        try {
            orders = JSON.parse(savedOrders);
            renderOrders();
        } catch (e) {
            console.error('Failed to parse saved orders:', e);
        }
    }
}

// Load support messages from localStorage
function loadSupportMessages() {
    const savedMessages = localStorage.getItem('supportMessages');
    if (savedMessages) {
        try {
            supportMessages = JSON.parse(savedMessages);
            renderSupportMessages();
        } catch (e) {
            console.error('Failed to parse saved support messages:', e);
        }
    }
}

// Render products in the table
function renderProducts() {
    if (!productsList) return;

    if (products.length === 0) {
        productsList.innerHTML = `
            <tr class="empty-state">
                <td colspan="8">No products found</td>
            </tr>
        `;
        return;
    }

    // Sort products by ID
    const sortedProducts = [...products].sort((a, b) => a.id - b.id);

    const productsHTML = sortedProducts.map(product => {
        const status = product.soldOut ? 'Sold Out' : 'In Stock';
        const statusClass = product.soldOut ? 'status-sold-out' : 'status-in-stock';

        return `
            <tr>
                <td>${product.id}</td>
                <td>
                    <div class="product-image-cell">
                        <img src="${product.image}" alt="${product.name}">
                    </div>
                </td>
                <td>${product.name}</td>
                <td>${product.category || ''}</td>
                <td>$${product.price.toFixed(2)}</td>
                <td>${product.rating}</td>
                <td>
                    <span class="status-label ${statusClass}">
                        ${status}
                    </span>
                </td>
                <td>
                    <div class="action-buttons">
                        <button class="action-button edit-product" data-id="${product.id}">
                            <i class="fas fa-edit"></i>
                        </button>
                        <button class="action-button delete-product" data-id="${product.id}">
                            <i class="fas fa-trash"></i>
                        </button>
                    </div>
                </td>
            </tr>
        `;
    }).join('');

    productsList.innerHTML = productsHTML;

    // Add event listeners to buttons
    document.querySelectorAll('.edit-product').forEach(button => {
        button.addEventListener('click', () => {
            const productId = parseInt(button.getAttribute('data-id'));
            openProductModal(productId);
        });
    });

    document.querySelectorAll('.delete-product').forEach(button => {
        button.addEventListener('click', () => {
            const productId = parseInt(button.getAttribute('data-id'));
            if (confirm(`Are you sure you want to delete this product?`)) {
                deleteProduct(productId);
            }
        });
    });
}

// Render orders in the table
function renderOrders() {
    if (!ordersList) return;

    if (orders.length === 0) {
        ordersList.innerHTML = `
            <tr class="empty-state">
                <td colspan="6">No orders found</td>
            </tr>
        `;
        return;
    }

    // Sort orders by date (newest first)
    const sortedOrders = [...orders].sort((a, b) => {
        return new Date(b.dateCreated || b.orderDate) - new Date(a.dateCreated || a.orderDate);
    });

    const ordersHTML = sortedOrders.map(order => {
        const date = formatDate(order.dateCreated || order.orderDate);
        const customer = `${order.firstName} ${order.lastName}`;
        const statusClass = `status-${order.orderStatus || 'pending'}`;
        const statusLabel = getStatusLabel(order.orderStatus || 'pending');

        return `
            <tr>
                <td>${order.orderId}</td>
                <td>${date}</td>
                <td>${customer}</td>
                <td>$${order.total.toFixed(2)}</td>
                <td>
                    <span class="status-label ${statusClass}">
                        ${statusLabel}
                    </span>
                </td>
                <td>
                    <div class="action-buttons">
                        <button class="action-button view-order" data-id="${order.orderId}">
                            <i class="fas fa-eye"></i>
                        </button>
                        <button class="action-button delete-order" data-id="${order.orderId}">
                            <i class="fas fa-trash"></i>
                        </button>
                    </div>
                </td>
            </tr>
        `;
    }).join('');

    ordersList.innerHTML = ordersHTML;

    // Add event listeners to buttons
    document.querySelectorAll('.view-order').forEach(button => {
        button.addEventListener('click', () => {
            const orderId = button.getAttribute('data-id');
            openOrderModal(orderId);
        });
    });

    document.querySelectorAll('.delete-order').forEach(button => {
        button.addEventListener('click', () => {
            const orderId = button.getAttribute('data-id');
            if (confirm(`Are you sure you want to delete this order?`)) {
                deleteOrder(orderId);
            }
        });
    });
}

// Render support messages in the table
function renderSupportMessages() {
    if (!supportList) return;

    if (supportMessages.length === 0) {
        supportList.innerHTML = `
            <tr class="empty-state">
                <td colspan="6">No support messages found</td>
            </tr>
        `;
        return;
    }

    // Sort messages by date (newest first)
    const sortedMessages = [...supportMessages].sort((a, b) => {
        return new Date(b.createdAt) - new Date(a.createdAt);
    });

    const messagesHTML = sortedMessages.map((message, index) => {
        const date = formatDate(message.createdAt);
        const customer = message.customerName || 'Unknown';
        const statusClass = message.isRead ? 'status-read' : 'status-unread';
        const statusLabel = message.isRead ? 'Read' : 'Unread';
        const messagePreview = message.message.length > 50 ? message.message.substring(0, 50) + '...' : message.message;

        return `
            <tr>
                <td>${message.orderNumber}</td>
                <td>${customer}</td>
                <td>${date}</td>
                <td>${messagePreview}</td>
                <td>
                    <span class="status-label ${statusClass}">
                        ${statusLabel}
                    </span>
                </td>
                <td>
                    <div class="action-buttons">
                        <button class="action-button reply-message" data-id="${index}">
                            <i class="fas fa-reply"></i>
                        </button>
                        ${!message.isRead ? `
                            <button class="action-button mark-read" data-id="${index}">
                                <i class="fas fa-check"></i>
                            </button>
                        ` : ''}
                        <button class="action-button delete-message" data-id="${index}">
                            <i class="fas fa-trash"></i>
                        </button>
                    </div>
                </td>
            </tr>
        `;
    }).join('');

    supportList.innerHTML = messagesHTML;

    // Add event listeners to buttons
    document.querySelectorAll('.reply-message').forEach(button => {
        button.addEventListener('click', () => {
            const messageId = parseInt(button.getAttribute('data-id'));
            openReplyModal(messageId);
        });
    });

    document.querySelectorAll('.mark-read').forEach(button => {
        button.addEventListener('click', () => {
            const messageId = parseInt(button.getAttribute('data-id'));
            markMessageAsRead(messageId);
        });
    });

    document.querySelectorAll('.delete-message').forEach(button => {
        button.addEventListener('click', () => {
            const messageId = parseInt(button.getAttribute('data-id'));
            if (confirm(`Are you sure you want to delete this message?`)) {
                deleteMessage(messageId);
            }
        });
    });
}

// Open product modal for add/edit
function openProductModal(productId = null) {
    const modalTitle = document.getElementById('product-modal-title');
    const form = document.getElementById('product-form');
    const imagePreview = document.getElementById('image-preview');

    if (!modalTitle || !form || !imagePreview) return;

    // Reset form
    form.reset();
    imagePreview.innerHTML = '';

    // Set modal title and populate form if editing
    if (productId) {
        const product = products.find(p => p.id === productId);
        if (product) {
            modalTitle.textContent = 'Edit Product';

            // Populate form fields
            document.getElementById('product-id').value = product.id;
            document.getElementById('product-name').value = product.name;
            document.getElementById('product-category').value = product.category || '';
            document.getElementById('product-price').value = product.price;
            document.getElementById('product-rating').value = product.rating;
            document.getElementById('product-image').value = product.image;
            document.getElementById('product-sold-out').checked = product.soldOut || false;

            // Show image preview
            if (product.image) {
                imagePreview.innerHTML = `<img src="${product.image}" alt="${product.name}">`;
            }

            currentProductId = product.id;
        }
    } else {
        modalTitle.textContent = 'Add Product';
        currentProductId = null;
    }

    // Show modal
    productModal.classList.add('active');
}

// Close product modal
function closeProductModal() {
    productModal.classList.remove('active');
    currentProductId = null;
}

// Handle product form submission
function handleProductFormSubmit() {
    const id = document.getElementById('product-id').value;
    const name = document.getElementById('product-name').value;
    const category = document.getElementById('product-category').value;
    const price = parseFloat(document.getElementById('product-price').value);
    const rating = parseInt(document.getElementById('product-rating').value);
    const image = document.getElementById('product-image').value;
    const soldOut = document.getElementById('product-sold-out').checked;

    if (!name || !price || !rating || !image) {
        alert('Please fill in all required fields');
        return;
    }

    // Create product object
    const product = {
        id: id ? parseInt(id) : getNextProductId(),
        name,
        category,
        price,
        rating,
        image,
        soldOut
    };

    // Add or update product
    if (currentProductId) {
        // Update existing product
        const index = products.findIndex(p => p.id === currentProductId);
        if (index !== -1) {
            products[index] = product;
        }
    } else {
        // Add new product
        products.push(product);
    }

    // Save products to localStorage
    saveProducts();

    // Close modal and render products
    closeProductModal();
    renderProducts();
}

// Delete product
function deleteProduct(productId) {
    // Remove product from array
    products = products.filter(p => p.id !== productId);

    // Save products to localStorage
    saveProducts();

    // Render products
    renderProducts();
}

// Save products to localStorage
function saveProducts() {
    localStorage.setItem('products', JSON.stringify(products));
    localStorage.setItem('adminProducts', JSON.stringify(products));
}

// Get next product ID
function getNextProductId() {
    if (products.length === 0) return 1;
    return Math.max(...products.map(p => p.id)) + 1;
}

// Update image preview
function updateImagePreview() {
    const imageUrl = document.getElementById('product-image').value;
    const imagePreview = document.getElementById('image-preview');

    if (!imagePreview) return;

    if (imageUrl) {
        imagePreview.innerHTML = `<img src="${imageUrl}" alt="Preview">`;
    } else {
        imagePreview.innerHTML = '';
    }
}

// Open order modal
function openOrderModal(orderId) {
    if (!orderModal) return;

    // Find order
    const order = orders.find(o => o.orderId === orderId);
    if (!order) return;

    currentOrderId = orderId;

    // Render order details
    const orderModalContent = document.getElementById('order-modal-content');
    if (!orderModalContent) return;

    const date = formatDate(order.dateCreated || order.orderDate);
    const statusOptions = ['pending', 'confirmed', 'shipped', 'delivered'];
    const statusSelectOptions = statusOptions.map(status => {
        const selected = status === order.orderStatus ? 'selected' : '';
        return `<option value="${status}" ${selected}>${getStatusLabel(status)}</option>`;
    }).join('');

    // Get product details for items in the order
    const orderItems = (order.items || []).map(item => {
        const product = products.find(p => p.id === item.productId);
        if (!product) return null;

        return {
            ...product,
            quantity: item.quantity,
            total: product.price * item.quantity
        };
    }).filter(Boolean);

    // Calculate subtotal
    const subtotal = orderItems.reduce((total, item) => total + item.total, 0);

    // Render order details
    orderModalContent.innerHTML = `
        <div class="order-details">
            <div class="order-header">
                <h4>Order #${order.orderId}</h4>
                <div class="order-status-select">
                    <label for="order-status">Status:</label>
                    <select id="order-status">
                        ${statusSelectOptions}
                    </select>
                </div>
            </div>

            <div class="order-info">
                <div class="info-group">
                    <div class="info-label">Order Date</div>
                    <div class="info-value">${date}</div>
                </div>
                <div class="info-group">
                    <div class="info-label">Customer</div>
                    <div class="info-value">${order.firstName} ${order.lastName}</div>
                </div>
                <div class="info-group">
                    <div class="info-label">Email</div>
                    <div class="info-value">${order.email}</div>
                </div>
                <div class="info-group">
                    <div class="info-label">Phone</div>
                    <div class="info-value">${order.phone}</div>
                </div>
            </div>

            <div class="shipping-info">
                <h4>Shipping Address</h4>
                <p>${order.address}</p>
                <p>${order.address2 ? order.address2 + '<br>' : ''}</p>
                <p>${order.city}, ${order.province} ${order.postalCode}</p>
            </div>

            <div class="order-items">
                <h4>Order Items</h4>
                ${orderItems.map(item => `
                    <div class="order-item">
                        <img src="${item.image}" alt="${item.name}" class="order-item-image">
                        <div class="order-item-details">
                            <div class="order-item-title">${item.name}</div>
                            <div class="order-item-price">$${item.price.toFixed(2)} × ${item.quantity}</div>
                        </div>
                        <div class="order-item-total">$${item.total.toFixed(2)}</div>
                    </div>
                `).join('')}
            </div>

            <div class="order-summary">
                <div class="summary-row">
                    <span>Subtotal</span>
                    <span>$${subtotal.toFixed(2)}</span>
                </div>
                <div class="summary-row">
                    <span>Shipping</span>
                    <span>Free</span>
                </div>
                <div class="summary-row">
                    <span>Tax</span>
                    <span>$${(subtotal * 0.05).toFixed(2)}</span>
                </div>
                <div class="summary-row summary-total">
                    <span>Total</span>
                    <span>$${order.total.toFixed(2)}</span>
                </div>
            </div>
        </div>
    `;

    // Show modal
    orderModal.classList.add('active');
}

// Close order modal
function closeOrderModal() {
    if (!orderModal) return;

    orderModal.classList.remove('active');
    currentOrderId = null;
}

// Update order status
function updateOrderStatus() {
    if (!currentOrderId) return;

    const statusSelect = document.getElementById('order-status');
    if (!statusSelect) return;

    const newStatus = statusSelect.value;

    // Find order and update status
    const orderIndex = orders.findIndex(o => o.orderId === currentOrderId);
    if (orderIndex !== -1) {
        orders[orderIndex].orderStatus = newStatus;

        // If status is shipped, add shipping date
        if (newStatus === 'shipped' && !orders[orderIndex].shippingDate) {
            orders[orderIndex].shippingDate = new Date().toISOString();
        }

        // If status is delivered, add delivery date
        if (newStatus === 'delivered' && !orders[orderIndex].deliveryDate) {
            orders[orderIndex].deliveryDate = new Date().toISOString();
        }

        // Save orders to localStorage
        localStorage.setItem('orders', JSON.stringify(orders));

        // Close modal and render orders
        closeOrderModal();
        renderOrders();
    }
}

// Delete order
function deleteOrder(orderId) {
    // Remove order from array
    orders = orders.filter(o => o.orderId !== orderId);

    // Save orders to localStorage
    localStorage.setItem('orders', JSON.stringify(orders));

    // Render orders
    renderOrders();
}

// Open reply modal
function openReplyModal(messageId) {
    if (!replyModal) return;

    // Find message
    const message = supportMessages[messageId];
    if (!message) return;

    currentMessageId = messageId;

    // Populate form
    document.getElementById('message-id').value = messageId;
    document.getElementById('message-content').textContent = message.message;
    document.getElementById('reply-message').value = message.reply || '';

    // Show modal
    replyModal.classList.add('active');
}

// Close reply modal
function closeReplyModal() {
    if (!replyModal) return;

    replyModal.classList.remove('active');
    currentMessageId = null;
}

// Handle reply form submission
function handleReplyFormSubmit() {
    const messageId = parseInt(document.getElementById('message-id').value);
    const replyText = document.getElementById('reply-message').value;

    if (isNaN(messageId) || !replyText) return;

    // Update message
    supportMessages[messageId].reply = replyText;
    supportMessages[messageId].replyDate = new Date().toISOString();
    supportMessages[messageId].isRead = true;

    // Save messages to localStorage
    localStorage.setItem('supportMessages', JSON.stringify(supportMessages));

    // Close modal and render messages
    closeReplyModal();
    renderSupportMessages();
}

// Mark message as read
function markMessageAsRead(messageId) {
    // Update message
    supportMessages[messageId].isRead = true;

    // Save messages to localStorage
    localStorage.setItem('supportMessages', JSON.stringify(supportMessages));

    // Render messages
    renderSupportMessages();
}

// Delete message
function deleteMessage(messageId) {
    // Remove message from array
    supportMessages.splice(messageId, 1);

    // Save messages to localStorage
    localStorage.setItem('supportMessages', JSON.stringify(supportMessages));

    // Render messages
    renderSupportMessages();
}

// Format date
function formatDate(dateString) {
    if (!dateString) return 'N/A';

    const date = new Date(dateString);

    return date.toLocaleDateString('en-US', {
        year: 'numeric',
        month: 'short',
        day: 'numeric',
        hour: '2-digit',
        minute: '2-digit'
    });
}

// Get status label
function getStatusLabel(status) {
    switch (status) {
        case 'pending': return 'Pending';
        case 'confirmed': return 'Confirmed';
        case 'shipped': return 'Shipped';
        case 'delivered': return 'Delivered';
        default: return 'Pending';
    }
}

// Filter orders
function filterOrders(query) {
    if (!ordersList) return;

    query = query.toLowerCase().trim();

    if (!query) {
        renderOrders();
        return;
    }

    // Filter orders
    const filteredOrders = orders.filter(order => {
        return (
            order.orderId.toLowerCase().includes(query) ||
            `${order.firstName} ${order.lastName}`.toLowerCase().includes(query) ||
            order.email.toLowerCase().includes(query) ||
            order.orderStatus.toLowerCase().includes(query)
        );
    });

    // Sort filtered orders
    const sortedOrders = filteredOrders.sort((a, b) => {
        return new Date(b.dateCreated) - new Date(a.dateCreated);
    });

    // Render filtered orders
    if (sortedOrders.length === 0) {
        ordersList.innerHTML = `
            <tr class="empty-state">
                <td colspan="6">No orders found matching "${query}"</td>
            </tr>
        `;
        return;
    }

    const ordersHTML = sortedOrders.map(order => {
        const date = formatDate(order.dateCreated);
        const customer = `${order.firstName} ${order.lastName}`;
        const statusClass = `status-${order.orderStatus}`;
        const statusLabel = getStatusLabel(order.orderStatus);

        return `
            <tr>
                <td>${order.orderId}</td>
                <td>${date}</td>
                <td>${customer}</td>
                <td>$${order.total.toFixed(2)}</td>
                <td>
                    <span class="status-label ${statusClass}">
                        ${statusLabel}
                    </span>
                </td>
                <td>
                    <div class="action-buttons">
                        <button class="action-button view-order" data-id="${order.orderId}">
                            <i class="fas fa-eye"></i>
                        </button>
                        <button class="action-button delete-order" data-id="${order.orderId}">
                            <i class="fas fa-trash"></i>
                        </button>
                    </div>
                </td>
            </tr>
        `;
    }).join('');

    ordersList.innerHTML = ordersHTML;

    // Add event listeners to buttons
    document.querySelectorAll('.view-order').forEach(button => {
        button.addEventListener('click', () => {
            const orderId = button.getAttribute('data-id');
            openOrderModal(orderId);
        });
    });

    document.querySelectorAll('.delete-order').forEach(button => {
        button.addEventListener('click', () => {
            const orderId = button.getAttribute('data-id');
            if (confirm(`Are you sure you want to delete this order?`)) {
                deleteOrder(orderId);
            }
        });
    });
}

// Filter products
function filterProducts(query) {
    // Similar to filterOrders but for products
    // Implementation left for brevity
}

// Filter support messages
function filterSupportMessages(query) {
    // Similar to filterOrders but for support messages
    // Implementation left for brevity
}

// Initialize the admin panel
setupNavigation();
