// DOM Elements
const orderItems = document.getElementById('checkout-items');
const subtotalAmount = document.getElementById('subtotal');
const shippingAmount = document.getElementById('shipping');
const taxAmount = document.getElementById('tax');
const totalAmount = document.getElementById('total');
const checkoutForm = document.getElementById('checkout-form');
const standardShippingRadio = document.querySelector('input[value="standard"]');
const expressShippingRadio = document.querySelector('input[value="express"]');

// Variables
let cart = [];
let subtotal = 0;
let shipping = 0;
let tax = 0;
let total = 0;
const TAX_RATE = 0.05; // 5% tax rate

// Event Listeners
document.addEventListener('DOMContentLoaded', () => {
    loadCart();
    setupEventListeners();
    console.log("Checkout page loaded with cart:", cart);
});

function setupEventListeners() {
    // Form submission
    if (checkoutForm) {
        checkoutForm.addEventListener('submit', handleFormSubmit);
    }

    // Shipping method change
    if (standardShippingRadio) {
        standardShippingRadio.addEventListener('change', updateOrderSummary);
    }

    if (expressShippingRadio) {
        expressShippingRadio.addEventListener('change', updateOrderSummary);
    }
}

// Load cart from localStorage
function loadCart() {
    const savedCart = localStorage.getItem('cart');
    if (savedCart) {
        try {
            cart = JSON.parse(savedCart);
            console.log("Cart loaded from localStorage:", cart);
            displayOrderItems();
            updateOrderSummary();
        } catch (e) {
            console.error('Failed to parse saved cart:', e);
            // Redirect to cart page if there's an error
            window.location.href = 'index.html';
        }
    } else {
        console.warn("No cart found in localStorage");
        // Redirect to cart page if no items
        window.location.href = 'index.html';
    }
}

// Display order items
function displayOrderItems() {
    if (!orderItems) {
        console.warn("Order items container not found");
        return; // Skip if the element doesn't exist
    }

    if (cart.length === 0) {
        console.warn("Cart is empty");
        orderItems.innerHTML = '<p>No items in cart</p>';
        return;
    }

    console.log("Displaying order items:", cart);
    orderItems.innerHTML = '';

    // Get products information from localStorage
    let products = [];
    const savedProducts = localStorage.getItem('products');
    if (savedProducts) {
        try {
            products = JSON.parse(savedProducts);
        } catch (e) {
            console.error('Failed to parse saved products:', e);
        }
    }

    cart.forEach(item => {
        // Find product details if available
        let productName = item.name || 'Unknown Product';
        let productImage = item.image || '';
        let productPrice = item.price || 0;

        // If we have a product ID, try to get more details from products list
        if (item.id && products.length > 0) {
            const product = products.find(p => p.id === item.id);
            if (product) {
                productName = product.name;
                productImage = product.image;
                productPrice = product.price;
            }
        }

        const orderItem = document.createElement('div');
        orderItem.className = 'order-item';
        orderItem.innerHTML = `
            <img src="${productImage}" alt="${productName}" class="order-item-image">
            <div class="order-item-details">
                <div class="order-item-title">${productName}</div>
                <div class="order-item-price">$${productPrice.toFixed(2)}</div>
                <div class="order-item-quantity">Quantity: ${item.quantity}</div>
            </div>
        `;
        orderItems.appendChild(orderItem);
    });
}

// Update order summary
function updateOrderSummary() {
    console.log("Updating order summary");
    // Calculate subtotal
    subtotal = cart.reduce((total, item) => total + (item.price * item.quantity), 0);
    console.log("Calculated subtotal:", subtotal);

    // Calculate shipping cost
    shipping = expressShippingRadio && expressShippingRadio.checked ? 10 : 0;
    console.log("Shipping cost:", shipping);

    // Calculate tax
    tax = subtotal * TAX_RATE;
    console.log("Tax amount:", tax);

    // Calculate total
    total = subtotal + shipping + tax;
    console.log("Total order amount:", total);

    // Update display
    if (subtotalAmount) {
        subtotalAmount.textContent = `$${subtotal.toFixed(2)}`;
    }

    if (shippingAmount) {
        shippingAmount.textContent = shipping === 0 ? 'Free' : `$${shipping.toFixed(2)}`;
    }

    if (taxAmount) {
        taxAmount.textContent = `$${tax.toFixed(2)}`;
    }

    if (totalAmount) {
        totalAmount.textContent = `$${total.toFixed(2)}`;
    }

    // Save the totals to localStorage for payment page
    localStorage.setItem('orderTotals', JSON.stringify({
        subtotal,
        shipping,
        tax,
        total
    }));
}

// Handle form submission
function handleFormSubmit(e) {
    e.preventDefault();
    console.log("Form submitted");

    // Get form data
    const formData = new FormData(checkoutForm);

    // Validate form
    const fullName = formData.get('fullName');
    const email = formData.get('email');
    const phone = formData.get('phone');
    const address = formData.get('address');
    const city = formData.get('city');
    const postalCode = formData.get('postalCode');
    const country = formData.get('country');
    const shippingMethod = formData.get('shippingMethod');

    if (!fullName || !email || !phone || !address || !city || !postalCode || !country) {
        alert('Please fill in all required fields');
        return;
    }

    // Parse name into first and last name for admin panel compatibility
    const nameParts = fullName.split(' ');
    const firstName = nameParts[0] || '';
    const lastName = nameParts.slice(1).join(' ') || '';

    // Recalculate totals to ensure accuracy
    updateOrderSummary();

    // Generate order ID
    const orderId = generateOrderId();
    const orderDate = new Date().toISOString();

    // Create customer info object in admin-compatible format
    const customerInfo = {
        email: email,
        phone: phone,
        firstName: firstName,
        lastName: lastName,
        address: address,
        city: city,
        postalCode: postalCode,
        province: country, // Using country as province for compatibility
        ageVerification: true,
        orderId: orderId,
        orderDate: orderDate,
        orderStatus: 'pending',
        paymentStatus: 'pending'
    };

    // Convert cart items to format for admin panel
    const cartItems = cart.map(item => ({
        productId: item.id,
        quantity: item.quantity
    }));

    // Create complete order object for admin panel
    const order = {
        ...customerInfo,
        items: cartItems,
        subtotal: subtotal,
        shipping: shipping,
        tax: tax,
        total: total,
        dateCreated: orderDate
    };

    console.log("Creating order:", order);

    // Save order info for user
    localStorage.setItem('checkoutInfo', JSON.stringify(customerInfo));
    localStorage.setItem('currentOrder', JSON.stringify(order));

    // Save to orders collection for admin panel
    let orders = [];
    try {
        const savedOrders = localStorage.getItem('orders');
        if (savedOrders) {
            orders = JSON.parse(savedOrders);
        }
    } catch(e) {
        console.error('Error parsing saved orders:', e);
    }

    orders.push(order);
    localStorage.setItem('orders', JSON.stringify(orders));

    // Clear cart
    // We'll keep the cart until payment is complete, then clear it
    // localStorage.removeItem('cart');

    // Show confirmation and redirect to payment
    alert(`Your order has been created! Order ID: ${orderId}. Proceeding to payment.`);
    window.location.href = `payment.html?orderId=${orderId}`;
}

// Generate unique order ID
function generateOrderId() {
    // Create ID in CT-XXXXXX format to match the TypeScript app
    const characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
    let result = 'CT-';
    for (let i = 0; i < 6; i++) {
        result += characters.charAt(Math.floor(Math.random() * characters.length));
    }
    return result;
}

// Helper function to show notification
function showNotification(message, type = 'success') {
    const notification = document.createElement('div');
    notification.className = `notification ${type}`;
    notification.textContent = message;

    document.body.appendChild(notification);

    setTimeout(() => {
        notification.classList.add('show');
    }, 10);

    setTimeout(() => {
        notification.classList.remove('show');
        setTimeout(() => {
            notification.remove();
        }, 300);
    }, 3000);
}
