// DOM Elements
const trackOrderForm = document.getElementById('track-order-form');
const orderIdInput = document.getElementById('order-id');
const orderResult = document.getElementById('order-result');
const supportSection = document.getElementById('support-section');
const supportButton = document.getElementById('support-button');
const supportModal = document.getElementById('support-modal');
const closeModalBtn = document.getElementById('close-modal');
const supportForm = document.getElementById('support-form');
const supportOrderIdInput = document.getElementById('support-order-id');

// Event Listeners
document.addEventListener('DOMContentLoaded', () => {
    setupEventListeners();

    // Check if there's an order ID in URL (from redirect)
    const urlParams = new URLSearchParams(window.location.search);
    const orderId = urlParams.get('orderId');
    if (orderId) {
        orderIdInput.value = orderId;
        trackOrder(orderId);
    }
});

function setupEventListeners() {
    // Track order form
    if (trackOrderForm) {
        trackOrderForm.addEventListener('submit', (e) => {
            e.preventDefault();
            const orderId = orderIdInput.value.trim();
            if (orderId) {
                trackOrder(orderId);
            }
        });
    }

    // Support button
    if (supportButton) {
        supportButton.addEventListener('click', () => {
            openSupportModal();
        });
    }

    // Close modal button
    if (closeModalBtn) {
        closeModalBtn.addEventListener('click', () => {
            closeSupportModal();
        });
    }

    // Support form
    if (supportForm) {
        supportForm.addEventListener('submit', (e) => {
            e.preventDefault();
            handleSupportForm();
        });
    }
}

// Find order by id
function findOrderById(orderId) {
    // Get orders from localStorage
    const savedOrders = localStorage.getItem('orders');
    if (!savedOrders) return null;

    try {
        const orders = JSON.parse(savedOrders);
        return orders.find(order => order.orderId === orderId);
    } catch (e) {
        console.error('Error parsing orders:', e);
        return null;
    }
}

// Format date for display
function formatDate(dateString) {
    if (!dateString) return 'N/A';

    const date = new Date(dateString);
    return date.toLocaleDateString('en-US', {
        year: 'numeric',
        month: 'long',
        day: 'numeric',
        hour: '2-digit',
        minute: '2-digit'
    });
}

// Get status class based on order status
function getStatusClass(status) {
    switch (status) {
        case 'pending': return 'status-pending';
        case 'confirmed': return 'status-confirmed';
        case 'shipped': return 'status-shipped';
        case 'delivered': return 'status-delivered';
        default: return 'status-pending';
    }
}

// Get status label based on order status
function getStatusLabel(status) {
    switch (status) {
        case 'pending': return 'Pending';
        case 'confirmed': return 'Confirmed';
        case 'shipped': return 'Shipped';
        case 'delivered': return 'Delivered';
        default: return 'Pending';
    }
}

// Track order
function trackOrder(orderId) {
    const order = findOrderById(orderId);

    if (!order) {
        orderResult.innerHTML = `
            <div class="order-not-found">
                <h3>Order Not Found</h3>
                <p>We couldn't find an order with the ID: ${orderId}</p>
                <p>Please check your order ID and try again.</p>
            </div>
        `;
        orderResult.style.display = 'block';
        supportSection.style.display = 'none';
        return;
    }

    // Get product info for items
    const products = JSON.parse(localStorage.getItem('products')) || [];

    // Map order items with product details
    const orderItems = order.items.map(item => {
        const product = products.find(p => p.id === item.productId) || {
            name: `Product #${item.productId}`,
            price: 0,
            image: ''
        };

        return {
            ...product,
            quantity: item.quantity,
            total: product.price * item.quantity
        };
    });

    // Calculate subtotal
    const subtotal = orderItems.reduce((total, item) => total + item.total, 0);

    // Render order details
    orderResult.innerHTML = `
        <div class="order-details">
            <div class="order-header">
                <div class="order-title">Order #${order.orderId}</div>
                <div class="order-status ${getStatusClass(order.orderStatus)}">
                    ${getStatusLabel(order.orderStatus)}
                </div>
            </div>

            <div class="order-info">
                <div class="info-group">
                    <div class="info-label">Order Date</div>
                    <div class="info-value">${formatDate(order.orderDate)}</div>
                </div>

                <div class="info-group">
                    <div class="info-label">Customer</div>
                    <div class="info-value">${order.firstName} ${order.lastName}</div>
                </div>

                <div class="info-group">
                    <div class="info-label">Email</div>
                    <div class="info-value">${order.email}</div>
                </div>

                <div class="info-group">
                    <div class="info-label">Phone</div>
                    <div class="info-value">${order.phone}</div>
                </div>
            </div>

            <div class="shipping-info">
                <h3>Shipping Address</h3>
                <p>${order.address}</p>
                <p>${order.city}, ${order.province} ${order.postalCode}</p>
            </div>

            <div class="tracking-stages">
                <div class="tracking-line"></div>

                <div class="tracking-stage ${order.orderStatus !== 'pending' ? 'stage-complete' : 'stage-current'}">
                    <div class="stage-icon">
                        <i class="fas fa-clipboard-check"></i>
                    </div>
                    <div class="stage-info">
                        <div class="stage-title">Order Placed</div>
                        <div class="stage-date">${formatDate(order.orderDate)}</div>
                    </div>
                </div>

                <div class="tracking-stage ${order.orderStatus === 'confirmed' ? 'stage-current' : order.orderStatus === 'shipped' || order.orderStatus === 'delivered' ? 'stage-complete' : ''}">
                    <div class="stage-icon">
                        <i class="fas fa-check"></i>
                    </div>
                    <div class="stage-info">
                        <div class="stage-title">Order Confirmed</div>
                        <div class="stage-date">${order.orderStatus === 'confirmed' || order.orderStatus === 'shipped' || order.orderStatus === 'delivered' ? 'Processing' : 'Pending'}</div>
                    </div>
                </div>

                <div class="tracking-stage ${order.orderStatus === 'shipped' ? 'stage-current' : order.orderStatus === 'delivered' ? 'stage-complete' : ''}">
                    <div class="stage-icon">
                        <i class="fas fa-shipping-fast"></i>
                    </div>
                    <div class="stage-info">
                        <div class="stage-title">Order Shipped</div>
                        <div class="stage-date">${order.orderStatus === 'shipped' || order.orderStatus === 'delivered' ? formatDate(order.shippingDate || order.orderDate) : 'Pending'}</div>
                    </div>
                </div>

                <div class="tracking-stage ${order.orderStatus === 'delivered' ? 'stage-current' : ''}">
                    <div class="stage-icon">
                        <i class="fas fa-box"></i>
                    </div>
                    <div class="stage-info">
                        <div class="stage-title">Order Delivered</div>
                        <div class="stage-date">${order.orderStatus === 'delivered' ? formatDate(order.deliveryDate || '') : 'Pending'}</div>
                    </div>
                </div>
            </div>

            <div class="order-items-list">
                <h3 class="order-items-heading">Order Items</h3>
                ${orderItems.map(item => `
                    <div class="order-item">
                        <img src="${item.image}" alt="${item.name}" class="order-item-image">
                        <div class="order-item-details">
                            <div class="order-item-title">${item.name}</div>
                            <div class="order-item-price">$${(item.price || 0).toFixed(2)}</div>
                            <div class="order-item-quantity">Quantity: ${item.quantity}</div>
                        </div>
                        <div class="order-item-total">$${(item.total || 0).toFixed(2)}</div>
                    </div>
                `).join('')}
            </div>

            <div class="order-summary">
                <div class="summary-row">
                    <span>Subtotal</span>
                    <span>$${subtotal.toFixed(2)}</span>
                </div>
                <div class="summary-row">
                    <span>Shipping</span>
                    <span>Free</span>
                </div>
                <div class="summary-row">
                    <span>Tax</span>
                    <span>$${(subtotal * 0.05).toFixed(2)}</span>
                </div>
                <div class="summary-row summary-total">
                    <span>Total</span>
                    <span>$${order.total.toFixed(2)}</span>
                </div>
            </div>
        </div>
    `;

    // Show order result and support section
    orderResult.style.display = 'block';
    supportSection.style.display = 'block';

    // Update support form with order ID
    if (supportOrderIdInput) {
        supportOrderIdInput.value = orderId;
    }
}

// Open support modal
function openSupportModal() {
    supportModal.classList.add('active');
}

// Close support modal
function closeSupportModal() {
    supportModal.classList.remove('active');
}

// Handle support form submission
function handleSupportForm() {
    const orderId = supportOrderIdInput.value;
    const message = document.getElementById('support-message').value;

    if (!orderId || !message) {
        alert('Please enter a message');
        return;
    }

    // Get customer info from order
    const order = findOrderById(orderId);

    if (!order) {
        alert('Order not found');
        return;
    }

    // Create support message
    const supportMessage = {
        orderNumber: orderId,
        message: message,
        createdAt: new Date().toISOString(),
        isRead: false,
        customerEmail: order.email,
        customerName: `${order.firstName} ${order.lastName}`
    };

    // Save support message
    let supportMessages = [];
    try {
        const savedMessages = localStorage.getItem('supportMessages');
        if (savedMessages) {
            supportMessages = JSON.parse(savedMessages);
        }
    } catch (e) {
        console.error('Error parsing support messages:', e);
    }

    supportMessages.push(supportMessage);
    localStorage.setItem('supportMessages', JSON.stringify(supportMessages));

    // Show success message
    alert('Your message has been sent. Our support team will get back to you soon.');

    // Close modal and reset form
    closeSupportModal();
    document.getElementById('support-message').value = '';
}
